### Imports
## Standard library modules
import datetime as dt
import json
import os
import pickle
import sys

## Third party librairies
from google.auth.transport.requests import Request
from google_auth_oauthlib.flow import InstalledAppFlow
from googleapiclient.discovery import build

## Local modules
import utils.checks
import utils.helpers
import utils.parsing
import utils.youtube.captions
import utils.youtube.channels
import utils.youtube.playlists
import utils.youtube.videos

### Software version checking
version, latest_release = utils.checks.check_version()
latest_url = "https://github.com/Killian42/QTube/releases/latest"

if latest_release is None:
    print("Failed to check the latest release version:\n")
else:
    comp = utils.checks.compare_software_versions(version, latest_release)
    if comp == "same":
        print("The latest stable version of the software is currently runnning.\n")
    elif comp == "older":
        print(
            f"You are currently running version {version}.\nConsider upgrading to the latest stable release ({latest_release}) at {latest_url}.\n"
        )
    elif comp == "newer":
        print(
            f"You are currently running version {version}.\nThis version is not a stable release. Consider installing the latest stable release ({latest_release}) at {latest_url}.\n"
        )

### User parameters loading
## JSON parameters file opening
try:
    user_params_dict = json.load(open("user_params.json"))
except FileNotFoundError:
    print(
        f"Error: user_params.json file not found.\nCheck that your parameter file is properly named."
    )
    sys.exit()
except Exception as e:
    print(f"An unexpected error occurred: {e}")
    sys.exit()

## Command line arguments
override_json = user_params_dict["override_json"]
if override_json:
    args = utils.parsing.parse_arguments()
    formatted_args = utils.parsing.format_arguments(args)

    # Rewrites JSON file parameters if options are provided in the terminal
    for k, v in formatted_args.items():
        if v is not None:
            user_params_dict[k] = v

## Parameters checking
if utils.checks.check_user_params(user_params_dict) is not True:
    print("User defined parameters are not correct. Check the template and retry.")
    sys.exit()
else:
    print("The user defined parameters are correctly formatted.\n")

## Verbosity options
verb = user_params_dict["verbosity"]
print(f"The following verbosity options are enabled: {verb}.\n")

### Youtube API login
credentials = None

## token.pickle stores the user's credentials from previously successful logins
if os.path.exists("token.pickle"):
    utils.helpers.print2(
        "Loading credentials from pickle file...", ["all", "credentials"], verb
    )

    with open("token.pickle", "rb") as token:
        credentials = pickle.load(token)

        utils.helpers.print2(
            "Credentials loaded from pickle file", ["all", "credentials"], verb
        )

## If there are no valid credentials available, then either refresh the token or log in.
if not credentials or not credentials.valid:
    if credentials and credentials.expired and credentials.refresh_token:
        utils.helpers.print2("Refreshing access token...", ["all", "credentials"], verb)

        credentials.refresh(Request())
        utils.helpers.print2("Access token refreshed\n", ["all", "credentials"], verb)
    else:
        utils.helpers.print2("Fetching New Tokens...", ["all", "credentials"], verb)
        flow = InstalledAppFlow.from_client_secrets_file(
            "client_secrets.json",
            scopes=[
                "https://www.googleapis.com/auth/youtube",
                "https://www.googleapis.com/auth/youtube.force-ssl",
            ],
        )

        flow.run_local_server(
            port=8080, prompt="consent", authorization_prompt_message=""
        )

        credentials = flow.credentials

        utils.helpers.print2("New token fetched\n", ["all", "credentials"], verb)

        # Save the credentials for the next run
        with open("token.pickle", "wb") as f:
            utils.helpers.print2(
                "Saving Credentials for Future Use...", ["all", "credentials"], verb
            )

            pickle.dump(credentials, f)
            utils.helpers.print2("Credentials saved\n", ["all", "credentials"], verb)

### Building API resource
youtube = build("youtube", "v3", credentials=credentials)

### Mock data ###
## Channels
mock_channels_info = {
    "2veritasium": "UC2LZO6swZ9SLUEOks3WnsfA",
    "30 Rock Official": "UCwLuX0LoZmlIFpfKvCHyELw",
    "acapellascience": "UCTev4RNBiu6lqtx8z1e87fQ",
    "acapellascience2": "UC2y3CMu4X5EX5IjrXqZEQKw",
    "Adequate ASMR": "UC_4CsQXbCI1LV7dug83qL8A",
    "Adé": "UC7wjRItE-Z5inb0xfgX-6jA",
    "Alasdair Beckett-King": "UCq5btGtqdn4CpvU0xTXaelA",
    "Alex Flournoy": "UCHAwDVSS8oDLLln07cNdU6A",
    "Alice au pays des étoiles": "UCFyTyQRqIj9pcpu7Xsu-U4w",
    "Alinéa ASMR": "UCf3VwNBuriywg4oge0e38DA",
    "Andrew Dotson": "UCnFmWQbVW_YbqPQZGNuq8sA",
    "Antoine Daniel - Les VOD": "UCEi0DIwuAQNe68OK_1hAN7w",
    "Apparat": "UCYTeaSzqH4QNnX_PR8JK0Rw",
    "Artur - The Library of Ohara": "UChbPNYQcJKpSERQZWA9BOqA",
    "ASMR con Kiki": "UCR9ehrySGCcxFNg8gCA2rsQ",
    "ASMR Glow": "UCFmL725KKPx2URVPvH3Gp8w",
    "ASMR Lauren": "UC8ACo6o9WRTYOrMVfXfhFpA",
    "ASMR with Kiki": "UCM740JWRTRDnSumg65flK2Q",
    "asmr zeitgeist": "UCzGEGjOCbgv9z9SF71QyI7g",
    "ASMR_Divinity": "UC_n9r4yRVXusIa6Cabl4wDw",
    "ASMR_Divinity_DE": "UCe6O7NLQE9Rvvcu9Jx3buEw",
    "ASMRSurge": "UCIKOy_q2VWDv1vzeoi7KgNw",
    "ASMRuOK ?": "UC_cMthuWcW5rg_eVvStyOtg",
    "AstroExploring": "UCc40o_F8ZIShT6D0l3Vu88A",
    "Aude WTFake": "UC8Ux-LOyEXeioYQ4LFzpBXw",
    "Aunty Donna": "UC_mneEC0wc29EGGmIsN_xLA",
    "Avides de recherche": "UC4Jrte_YtwWfANKNyzse5iA",
    "Axolot": "UC2_OG1L8DLTzQ7UrZVOk7OA",
    "Ayliean": "UChwcAFGJZVE2hqAiZSFSyug",
    "Barns Courtney": "UCOQhQVN8GaYU2VpuKFUIwhg",
    "Bazar du Grenier": "UCCMxHHciWRBBouzk-PGzmtQ",
    "BBC": "UCCj956IF62FbT7Gouszaj9w",
    "Best Of Antoine Daniel": "UCBuee5JCBlI_VuKjxmqtyUA",
    "Best Of du Grenier": "UClK4fpmIAz8V1BVafysM2WA",
    "bill wurtz": "UCq6aw03lNILzV96UvEAASfQ",
    "BLAST, Le souffle de l'info": "UC__xRB5L4toU9yYawt_lIKg",
    "Bloodywood": "UChDkP71cJOHop-iRgl_8pVg",
    "Borna Matosic": "UCaII61Vk-3JU8uHGIYS_TBQ",
    "Bright Grey ASMR": "UC53vVuTxfTUPZSZVPW1iitg",
    "Bucksttabu": "UCpBX15ZTsr2p0ByGFwB-Yzw",
    "C'est une autre histoire": "UCKjDY4joMPcoRMmd-G1yz1Q",
    "Calmos": "UCYBr8enT5x4-JIxcPY6y-_A",
    "Caroline Polachek": "UC_YiGpMGuBb1PbjqPQMf9MQ",
    "cassetteboy": "UC2ygfgkbAvBTSHyfM3F6WLQ",
    "CGP Grey": "UC2C_jShtL725hvbm1arSV9w",
    "CGPGrey2": "UC127Qy2ulgASLYvW4AuHJZQ",
    "Chat Sceptique": "UCOuIgj0CYCXCvjWywjDbauw",
    "CinnamonToastKen": "UCepq9z9ovYGxhNrvf6VMSjg",
    "Climen": "UC8MZDcFxb6FtogVEZ0Eyydg",
    "Com Nancay": "UC0UvM4Y13z1nvfarVzNVZrA",
    "Community": "UC083VJ23T17StE7R7Fm00jQ",
    "Confessions d'Histoire": "UCzj9-ZfpJ74vYv1RZzAWTVg",
    "ContraPoints": "UCNvsIonJdJ5E4EXMa65VYpA",
    "Corey Schafer": "UCCezIgC97PvUuR4_gbFUs5g",
    "CosmosMidnight": "UCiuv22PkUVH9o4hYGvwF7-w",
    "Crime Pays But Botany Doesn't": "UC3CBOpT2-NRvoc2ecFMDCsA",
    "DanyCaligula": "UCxJka_qnTVquoIL-PQV5POg",
    "Data Gueule": "UCm5wThREh298TkK8hCT9HuA",
    "davidpostoffice": "UCyYWQXJvjY1MQvx8LCdefcw",
    "Deus Ex Silicium": "UCH6ppHEvV3_WIXEwmhv9HEg",
    "Doctor Who": "UCcOkA2Xmk1valTOWSyKyp4g",
    "Doctor Who Poop": "UCdvn0_BjeBJgshpgaiqQ5nA",
    "Doctor Who: LOCKDOWN!": "UCoRhKoBcGwcCT8YJBxKrWLw",
    "DWPoop Shorts": "UCqaxKk9MFX52CCAiZLoEbZQ",
    "e-penser 2.0": "UCcziTK2NKeWtWQ6kB5tmQ8Q",
    "e-penser [best of twitch]": "UCJEZqCflPp4GMw9ezZEGuFQ",
    "Eevy ASMR": "UCvjJat2_IdezGfh2_pAdRwQ",
    "EISBRECHER official": "UCTtmwDCkWEdNtiY5p8zgU2g",
    "El Jj": "UCgkhWgBGRp0sdFy2MHDWfSg",
    "ElectroBOOM": "UCJ0-OtVpF0wOKEqT2Z1HEtA",
    "Elena ASMR": "UCRQAFkl4BDOokg_R35Uqj1A",
    "Emigrate official": "UCDB4RoqHlMLyJh8eRA6d4AA",
    "ERB": "UCMu5gPmKp5av0QCAajKTMhw",
    "ERB2": "UCaut53cnrdipyo47R-a3tEw",
    "Erdling - Topic": "UCr4q713eXzrXJhOSbXey5KA",
    "Espace des sciences": "UClDk0iyj99stPxD9NQUaVSQ",
    "Etonnarium": "UCNmLe68qKzdjuEpT_YTDFuA",
    "fastASMR": "UCHiof82PvgZrXFF-BRMvGDg",
    "FEUILLAGE": "UCGl2QLR344ry4Y20RV9dM3g",
    "Flammable Maths": "UCtAIs1VCQrymlAnw3mGonhw",
    "Flander's Company": "UCdrSLDITndxHz9xVlsMmSBQ",
    "François Descraques": "UCpJWP5_DNPdIhrJIpRkZPoA",
    "FrenchBall": "UCQ5nOq77BZoKN_sB2iZsJ6Q",
    "Friendly Space Ninja": "UCLuI5IP4nBr82VxClxp7Teg",
    "Grouse House": "UCNuaFLcbAeycQAIAW5s7T0Q",
    "guiguiamon": "UCs_wVFgXJonj-HOQ5k61qFg",
    "hbomberguy": "UClt01z1wHHT7c5lKcU8pxRQ",
    "Heather Feather ASMR": "UC2eddeJoyByJBjE4CYXwNXQ",
    "Hot Department": "UCH6Klw22jzn4W9n9tHMmhxQ",
    "Hygiène Mentale": "UCMFcMhePnH4onVHt2-ItPZw",
    "issibern": "UCR2u6yDeo61zhGJicVpUf2g",
    "iterorganization": "UCZzwQDDag5eP4Rs-2d4nX5g",
    "James Acaster": "UC-UZ_hCLhWxbpGMMbRxag4w",
    "Jay Exci": "UCpNs490-gDnuTaMXO3HWXFw",
    "Jean-Luc Dauvergne": "UCODeN-yDnJJH3wOqWaz536g",
    "Jeannot Nymouce": "UCND0gjuG9ltEWDvh82VJITg",
    "JellybeanASMR": "UCCjpp4TCjnRftS_LenXuSHw",
    "Joe Pera": "UCfBAKxelvdN2XDFBcofx7Dg",
    "Joueur Du Grenier": "UC_yP2DpIgs5Y1uWC0T03Chw",
    "Joul Psycho": "UCkw-P155uC_NIOHLW86jJlQ",
    "Kitboga": "UCm22FAXZMw1BaWeFszZxUKw",
    "KrisSdeNerf": "UC5nG2jBqTpOgBH2y8PWtZbw",
    "La Mezzanine": "UCJRljQ8OcyfzHBYpS_bDbow",
    "La Taverne Zététique": "UCpCTkZl_NO_PLa13W-42STw",
    "La Tronche en Biais": "UCq-8pBMM3I40QlrhM9ExXJQ",
    "LaBajon": "UCukbnzZSfOVmszwwHGK7tqw",
    "LanguagesWithKiki": "UCpf1Vd7FStvJYKOArlYxh2Q",
    "Lanterne Cosmique": "UCWYxQt9Y3y2CDzXLf2K7xCA",
    "LastWeekTonight": "UC3XTzVzaHQEd30rQbuvCtTQ",
    "Laurent Guérin": "UCmxhHj5N-FNpsvv7vVUy_tQ",
    "Le Myriogon": "UCvYEpQbJ81n2pjrQrKUrRog",
    "Le Réveilleur": "UC1EacOJoqsKaYxaDomTCTEQ",
    "Le Sense Of Wonder": "UCjsHDXUU3BjBCG7OaCbNDyQ",
    "Le Visiteur du Futur": "UCDiYyE0L05ce_TxDvsUz1rg",
    "les ferrailleurs du net": "UCyF9jUY-MGdxSI9csPgDmiQ",
    "Les Gribouillages de Rakidd": "UCaPyR4PwVd2Vn6KikzyIw9A",
    "Les Inconnus": "UCXY5L6p4n3COUBqaTJY-2tQ",
    "Les Kassos": "UCv88958LRDfndKV_Y7XmAnA",
    "Les Revues du Monde": "UCnf0fDz1vTYW-sl36wbVMbg",
    "Lindsey Stirling": "UCyC_4jvPzLiSkJkLIkA7B8g",
    "Linguisticae": "UCofQxJWd4qkqc7ZgaLkZfcw",
    "LORIS GIULIANO": "UCsTK8xMZKkrbTeWc8REbn8Q",
    "LPC2EOfficiel": "UCx6h0TtLlEbIyevSy6-JTKg",
    "L’instant détox": "UCRAbwEqGDnUBt_gPOkplGBA",
    "Madison Ryann Ward": "UCfqNUoJTci-tE6gfXVwwwXg",
    "MARGARITA LIFE": "UCyfyeKkA0LpnuWjg8pVHbig",
    "Marno ASMR": "UC4RdEwzh0r3CuTEElRQ6dpg",
    "MassageASMR": "UCgOfiuubHnhVrc9IEcSk1Nw",
    "Matt Dieterich": "UCK78bOVVEMLq-TnVRUaoeMQ",
    "Mediapart": "UCdnaDhU-LDQrIEEmSIfq0-Q",
    "MetsatollOfficial": "UCgXgC0JdvLqLqAoOFweiRsA",
    "Michael Spicer": "UC9gtLw0B8rZ7aPycaC88N-g",
    "Mickaël Launay": "UC4PasDd25MXqlXBogBw9CAg",
    "Mickelous ASMR": "UCHA3X29RPYbbnmL0LCrUQ9w",
    "MickelousProductions": "UCSGcKeHV4hbJWNoyuKMfOeA",
    "MinuteEarth": "UCeiYXex_fwgYDonaTcSIk6w",
    "minutephysics": "UCUHW94eEFW7hkUMVaZz4eDg",
    "Mock The Week": "UC9Ta8RQydQwHdFwzYt9cnYg",
    "Monsieur Phi": "UCqA8H22FwgBVcF3GJpp0MQw",
    "Monty Python": "UCGm3CO6LPcN-Y7HIuyE0Rew",
    "Moonlight Tingles": "UCwrQdoGGFvo0ToKWcM-HxhA",
    "More Kitboga": "UCWpQycBnpPxyWY6bBhr4Rbw",
    "MrAntoineDaniel": "UCtI6_1vGanPlH5lgVIDjJGQ",
    "MyFuckinMess": "UCZAAaq8tdpjGtMubXXuPjgg",
    "Napalm Records": "UCG7AaCh_CiG6pq_rRDNw72A",
    "NASA": "UCLA_DiR1FfKNvjuUpBHmylQ",
    "National Science Foundation News": "UCRuCgmzhczsm89jzPtN2Wuw",
    "Nebelhaus": "UC_xJ8WTZqPti1iCqxPFgwAw",
    "No Headphones ASMR": "UC5xtTcTCJFo1PeM76vyF-eQ",
    "No More Jockeys": "UCS8aP7SiA_eTfvT_Gruxzsw",
    "Noob & Olydri": "UCdHXMcWxwZr2qQpdCCOcSkw",
    "Noplan": "UCru3FcoymFzAeXwfSxfGPoQ",
    "Numberer1": "UCNMtM6Nf54U7jcvdQqpv8nw",
    "Numberphile": "UCoxcjq-8xIDTYp3uz647V5A",
    "Numberphile2": "UCyp1gCHZJU_fGWFf2rtMkCg",
    "Objectivity": "UCtwKon9qMt5YLVgQt1tvJKg",
    "OLG Bonus": "UC29GiGDjU6N53gNatKn7SkA",
    "On s'en Baluchon": "UCRGFxAYwNzTjlUApOS7sw3w",
    "OOMPH!": "UC4u1M7OPAeDls-l8hQOjeng",
    "Ost+Front - Topic": "UCuUEUTIAyHJefmC2cW9b4jQ",
    "Out Of Line Music": "UC7gQjDSfsNHJKbN3YC9p_3A",
    "P.H. Largillière": "UCkiEROFwOw8RzZBRgwLtnrg",
    "Parks and Recreation": "UC084FSD0cO4ZOS5SonULRCQ",
    "Parlons Y-stoire": "UCuzwN74da6dfHW69r4S2qJg",
    "Pepperpot Adventures": "UCZ7-4Ri6Riuun-NctrB8Vgg",
    "Pepperpot Team": "UCW5tIUvt5B1Qfq2NpWhHSuA",
    "PewDiePie": "UC-lHJZR3Gqxm24_Vd_AJ5Yw",
    "phelto": "UCSrg8YPpUJDNNVL1RxadCFw",
    "Philosophy Tube": "UC2PA-AKmVpU6NKCGtZq_rKQ",
    "Physics Girl": "UC7DdEm33SyaTDtWYGO2CwdA",
    "Point de vue social #PDVS": "UCK6mlWEjd5-wK1aOqL2zKQQ",
    "Powerwolf Official": "UCL25rDdQtKGs2r7a9rbuNYg",
    "Produit Internet": "UCE1Kq33TzjB6hawC-uwGe8w",
    "Professeur Sims": "UC8KD_PsFqubYcfOSnu_UYAA",
    "projet moz": "UCuaEKnzwFQgPqLrWTsxIG1Q",
    "RaffyTaphyASMR": "UCMWQbdU4kjCB49xkuQ8nYRw",
    "Rammstein Official": "UCYp3rk70ACGXQ4gFAiMr1SQ",
    "Rammstein Orchestra": "UC3xFLgma0E6SZJ8PlJ74RBg",
    "RammsteinWorldCom": "UCo1Tc2_YpAH3jgH-bpLbDIQ",
    "Ricky Gervais": "UCry7B7DGVgUIa6k4Tis_DJQ",
    "Rémi GAILLARD": "UCmPSwsooZq8an7xOLQQhAdw",
    "Rémi Gaillard Shorts": "UCCTBUevtjdvciHAQnRLngtw",
    "Réussite Critique": "UC7D9Q0WzEejlgdXywAgz79A",
    "Révisons Nos Classiques": "UCZHPwKyeypWwU8SNJSzQhCw",
    "Salade de FDP": "UCZgkWB93d2WyBfy4gEptZ6A",
    "Sam O'Nella Academy": "UC1DTYW241WD64ah5BFWn4JA",
    "Sci+": "UCaZRpfXzlHVchIJMpf-PVFw",
    "ScienceEtonnante": "UCaNlbnghtwlsGF-KzAFThqA",
    "Scilabus": "UCeR8BYZS7IHYjk_9Mh5JgkA",
    "Scinéma": "UCPF7JOWMDWZmnP_cQfyAezg",
    "seb ASMR": "UCi3wQ9w5N-jnzr1NO9uiO_g",
    "Sherlock": "UCkp_CAX1eIc5k5SavzbhN5w",
    "Smarter Every Day 2": "UC8VkNBOwvsTlFjoSnNSMmxw",
    "SmarterEveryDay": "UC6107grRI4m0o2-emgoDnAA",
    "softlygaloshes ASMR": "UCr6vWe5goPw6-4YknmrZioQ",
    "SovietWomble": "UCQD3awTLw9i8Xzh85FKsuJA",
    "SpaceX": "UCtI0Hodo5o5dUb67FeUjDeA",
    "St. Vincent": "UC76cjhGZXsVeYcC2ERml_BA",
    "Station Service": "UCzpz2sUuvZ6VtkfHPSI0REQ",
    "sylvie beaufils": "UCtC9Uyz7VYwhdKPmH-2JMCA",
    "Taskmaster": "UCT5C7yaO3RVuOgwP8JVAujQ",
    "Taskmaster: Minnesota": "UCG_vclOrIHcW1dWF_h4WsLA",
    "The Daily Show": "UCwWhs_6x42TyRM4Wstoq8HA",
    "The Late Show with Stephen Colbert": "UCMtFAi84ehTSYSE9XoHefig",
    "The Lutetium Project": "UC3iPHLGE9w0U4pVtmtmayzQ",
    "The Office": "UCa90xqK2odw1KV5wHU9WRhg",
    "The Slow Mo Guys": "UCUK0HBIBWgM2c4vsPhkYY4w",
    "The Slow Mo Guys 2": "UCgC4Nn0rqqdeqACnzaIMo_Q",
    "The Sound Traveler": "UC0tq0g5u2bo-TErZt7SJM6w",
    "Therapie TAXI": "UCw6eCoyUf6sOa5L6fouZO4w",
    "Thomas Hercouët": "UCm7KqKpv85JrIKPDjmuU8fg",
    "Tibees": "UC52kszkc08-acFOuogFl5jw",
    "Till Lindemann": "UCkjot4p29KLU0pwc0srHeGg",
    "Tingles and Rhythms ASMR": "UC316N1ILOxSc6fXBzrjs8ZA",
    "Toilettes Publiques Entertainment": "UCqVOzk96PQwvE_m15kLaiGg",
    "TomSka": "UCOYWgypDktXdb-HfZnSMK6A",
    "TomSka & Friends": "UC3tMH8u6yG3mSxi-qpfmpkA",
    "Torchwood": "UC8EY2Nlow8wdUMCBucHEaOg",
    "Tove Styrke": "UC6k9UMBwGhNGP8f8FgmOJIA",
    "Trigger Happy ASMR": "UCC3VMNxGyAR8EbZ3dAI9FiA",
    "UFR Sciences & Techniques": "UC_ZkWgJYrd9YMSG2AIBfgrw",
    "Université de Rennes": "UCAf9V2Z9-gf_Kmbzq-cfljg",
    "Unsterbliicher": "UCXxlXhwYAgallFY0LF92DtQ",
    "Veritasium": "UCHnyfMqiRRG1u-2MsSQLbXA",
    "Vled Tapas": "UCMkOKU7usWmqcpLDcWG9PtQ",
    "VOD du Grenier": "UCek7RokwPqKAM52v80ICOTQ",
    "Volande Grillé": "UCfGMQJUPnEPSeQF-XUUfy5Q",
    "Vsauce": "UC6nSFpj9HTCZ5t-N3Rm3-HA",
    "Vsauce2": "UCqmugCqELzhIMNYnsjScXXw",
    "Vsauce3": "UCwmFOfFuvRPI112vR5DNnrA",
    "Waftr": "UCgI-Kh8c6V4SyRoTsvnBA2A",
    "Wildeye Demon": "UCsM974SXGImdVC7KoAszNIQ",
    "WonderWhy": "UCcEPmwpXKrKzZahqjwpIAsQ",
    "YAENNIVER": "UCcu9EOcEDMhVm5s4iiqvStg",
    "Yam ASMR": "UCmCzIW22w_4LNTDY0j1sqWw",
    "Yes I'm a Designer": "UCT_of6HCtVZFpnnnLUeAGYA",
    "Zach Sherwin": "UCWMBAaI29L-eaUHY7f2wHEg",
    "Zaoui": "UCDNnYeTmKOEwJgHmCIPLRMw",
    "ZDF heute-show": "UCFqcNI0NaAA21NS9W3ExCRg",
    "ZDF MAGAZIN ROYALE": "UCNNEMxGKV1LsKZRt4vaIbvw",
    "Zeal & Ardor": "UCPg_FoJeD3drwPeS6xjD9FA",
    "小穎美食": "UCJJDD-Hy76jvUMRG-dpFkcw",
}

## Playlists
# Upload playlists
upload_playlist_ID_lst = [
    "UU2LZO6swZ9SLUEOks3WnsfA",
    "UUwLuX0LoZmlIFpfKvCHyELw",
    "UUTev4RNBiu6lqtx8z1e87fQ",
    "UU2y3CMu4X5EX5IjrXqZEQKw",
    "UU_4CsQXbCI1LV7dug83qL8A",
    "UU7wjRItE-Z5inb0xfgX-6jA",
    "UUq5btGtqdn4CpvU0xTXaelA",
    "UUHAwDVSS8oDLLln07cNdU6A",
    "UUFyTyQRqIj9pcpu7Xsu-U4w",
    "UUf3VwNBuriywg4oge0e38DA",
    "UUnFmWQbVW_YbqPQZGNuq8sA",
    "UUEi0DIwuAQNe68OK_1hAN7w",
    "UUYTeaSzqH4QNnX_PR8JK0Rw",
    "UUhbPNYQcJKpSERQZWA9BOqA",
    "UUR9ehrySGCcxFNg8gCA2rsQ",
    "UUFmL725KKPx2URVPvH3Gp8w",
    "UU8ACo6o9WRTYOrMVfXfhFpA",
    "UUM740JWRTRDnSumg65flK2Q",
    "UUzGEGjOCbgv9z9SF71QyI7g",
    "UU_n9r4yRVXusIa6Cabl4wDw",
    "UUe6O7NLQE9Rvvcu9Jx3buEw",
    "UUIKOy_q2VWDv1vzeoi7KgNw",
    "UU_cMthuWcW5rg_eVvStyOtg",
    "UUc40o_F8ZIShT6D0l3Vu88A",
    "UU8Ux-LOyEXeioYQ4LFzpBXw",
    "UU_mneEC0wc29EGGmIsN_xLA",
    "UU4Jrte_YtwWfANKNyzse5iA",
    "UU2_OG1L8DLTzQ7UrZVOk7OA",
    "UUhwcAFGJZVE2hqAiZSFSyug",
    "UUOQhQVN8GaYU2VpuKFUIwhg",
    "UUCMxHHciWRBBouzk-PGzmtQ",
    "UUCj956IF62FbT7Gouszaj9w",
    "UUBuee5JCBlI_VuKjxmqtyUA",
    "UUlK4fpmIAz8V1BVafysM2WA",
    "UUq6aw03lNILzV96UvEAASfQ",
    "UU__xRB5L4toU9yYawt_lIKg",
    "UUhDkP71cJOHop-iRgl_8pVg",
    "UUaII61Vk-3JU8uHGIYS_TBQ",
    "UU53vVuTxfTUPZSZVPW1iitg",
    "UUpBX15ZTsr2p0ByGFwB-Yzw",
    "UUKjDY4joMPcoRMmd-G1yz1Q",
    "UUYBr8enT5x4-JIxcPY6y-_A",
    "UU_YiGpMGuBb1PbjqPQMf9MQ",
    "UU2ygfgkbAvBTSHyfM3F6WLQ",
    "UU2C_jShtL725hvbm1arSV9w",
    "UU127Qy2ulgASLYvW4AuHJZQ",
    "UUOuIgj0CYCXCvjWywjDbauw",
    "UUepq9z9ovYGxhNrvf6VMSjg",
    "UU8MZDcFxb6FtogVEZ0Eyydg",
]

# Others
playlist_ID_a = (
    "PL9HlBqxluNV_8lWqhxz_Uy92I7EAAD2I8"  # valid and mine, less than 50 vids
)
playlist_ID_a2 = (
    "PL9HlBqxluNV8V7yoX5K-7-S3mSauzp65Z"  # valid and mine, more than 50 vids
)
playlist_ID_a3 = "PL9HlBqxluNV__uF2aKxE0AsEa2eqhfI2P"  # valid and mine, empty
playlist_ID_b = "PLWVbat-xv06kTAsL3RaPzNrJ1F5MZZun2"  # valid
playlist_ID_c = "PL9HlBqxluNV_8lWqhxz_Uy92I7EAAD2I7"  # invalid

## Responses
# Snippet
mock_two_vid_responses = {
    "kind": "youtube#videoListResponse",
    "etag": "DGJJsKADl5fqAGRAXxzF27QtCoM",
    "items": [
        {
            "kind": "youtube#video",
            "etag": "yKGN8XFPHRAEKWWXDam3_9H2E08",
            "id": "ynYsMu14BrA",
            "snippet": {
                "publishedAt": "2019-02-11T18:58:49Z",
                "channelId": "UC_OttpBEWWzSUlZbk5qmhSA",
                "title": "How To Pass As A Woman | Mia Mulder",
                "description": "What is passing? What does passing mean? How does it impact identity? \n\nThis video is about my own personal exploration about that term and what it means for me and how it makes me feel. My experiences are not universal but they are still my experiences. \n\nThis video is made from my perspective. I don't expect everyone to have a similar view on passing as me, and I think that's good. I don't want to make anyone feel like they *should* think about passing in any way. I just want to share my own perspective which I sometimes feel is overlooked in the greater conversation about passing, looks, appearance and identity. \n\nPlease don't read anything into this that I don't mean. If you have questions or anything you feel like I should clarify, please tell me in the comments. \n\nSarahs video on transitioning\nhttps://www.youtube.com/watch?v=3PClMhVAQWg\n\n------------\nPronouns: She/Her (Maybe?)\nInstagram: Mia_mulder\nTwitter: www.twitter.com/potatopolitics\nPatreon: www.patreon.com/MiaMulder\nOne Time Donations: www.ko-fi.com/miamulder\nwww.paypal.me/MiaMulder\n\n-------------\n\nReaders! Do You Read by Chris Zabriskie is licensed under a Creative Commons Attribution license (https://creativecommons.org/licenses/by/4.0/)\nSource: http://chriszabriskie.com/reappear/\nArtist: http://chriszabriskie.com/\n\nDirect to Video by Chris Zabriskie is licensed under a Creative Commons Attribution license (https://creativecommons.org/licenses/by/4.0/)\nSource: http://chriszabriskie.com/dtv/\nArtist: http://chriszabriskie.com/\n\nBrethren, Arise by Chris Zabriskie is licensed under a Creative Commons Attribution license (https://creativecommons.org/licenses/by/4.0/)\nSource: http://chriszabriskie.com/darkglow/\nArtist: http://chriszabriskie.com/",
                "thumbnails": {
                    "default": {
                        "url": "https://i.ytimg.com/vi/ynYsMu14BrA/default.jpg",
                        "width": 120,
                        "height": 90,
                    },
                    "medium": {
                        "url": "https://i.ytimg.com/vi/ynYsMu14BrA/mqdefault.jpg",
                        "width": 320,
                        "height": 180,
                    },
                    "high": {
                        "url": "https://i.ytimg.com/vi/ynYsMu14BrA/hqdefault.jpg",
                        "width": 480,
                        "height": 360,
                    },
                    "standard": {
                        "url": "https://i.ytimg.com/vi/ynYsMu14BrA/sddefault.jpg",
                        "width": 640,
                        "height": 480,
                    },
                },
                "channelTitle": "Mia Mulder",
                "tags": [
                    "identity",
                    "passing",
                    "woman",
                    "how to pass as a woman",
                    "how",
                    "to",
                    "pass",
                    "as",
                    "Mia Mulder",
                    "Mia",
                    "Mulder",
                    "trans",
                    "transgender",
                    "trans woman",
                    "transwoman",
                    "transition",
                    "cis",
                ],
                "categoryId": "22",
                "liveBroadcastContent": "none",
                "defaultLanguage": "en",
                "localized": {
                    "title": "How To Pass As A Woman | Mia Mulder",
                    "description": "What is passing? What does passing mean? How does it impact identity? \n\nThis video is about my own personal exploration about that term and what it means for me and how it makes me feel. My experiences are not universal but they are still my experiences. \n\nThis video is made from my perspective. I don't expect everyone to have a similar view on passing as me, and I think that's good. I don't want to make anyone feel like they *should* think about passing in any way. I just want to share my own perspective which I sometimes feel is overlooked in the greater conversation about passing, looks, appearance and identity. \n\nPlease don't read anything into this that I don't mean. If you have questions or anything you feel like I should clarify, please tell me in the comments. \n\nSarahs video on transitioning\nhttps://www.youtube.com/watch?v=3PClMhVAQWg\n\n------------\nPronouns: She/Her (Maybe?)\nInstagram: Mia_mulder\nTwitter: www.twitter.com/potatopolitics\nPatreon: www.patreon.com/MiaMulder\nOne Time Donations: www.ko-fi.com/miamulder\nwww.paypal.me/MiaMulder\n\n-------------\n\nReaders! Do You Read by Chris Zabriskie is licensed under a Creative Commons Attribution license (https://creativecommons.org/licenses/by/4.0/)\nSource: http://chriszabriskie.com/reappear/\nArtist: http://chriszabriskie.com/\n\nDirect to Video by Chris Zabriskie is licensed under a Creative Commons Attribution license (https://creativecommons.org/licenses/by/4.0/)\nSource: http://chriszabriskie.com/dtv/\nArtist: http://chriszabriskie.com/\n\nBrethren, Arise by Chris Zabriskie is licensed under a Creative Commons Attribution license (https://creativecommons.org/licenses/by/4.0/)\nSource: http://chriszabriskie.com/darkglow/\nArtist: http://chriszabriskie.com/",
                },
                "defaultAudioLanguage": "en",
            },
        },
        {
            "kind": "youtube#video",
            "etag": "il1LaXJtlIZx4yN_3zkLBa16-f0",
            "id": "9KZ0euKnIak",
            "snippet": {
                "publishedAt": "2021-07-12T17:15:19Z",
                "channelId": "UCq_ZoGyeCb-1nUCD9z8Fzcg",
                "title": "Richard Osman's House of Games - S03E26 (11 Nov 2019)",
                "description": "Jay Blades, Rachel Parris, Shaun Keaveny, Jan Ravens\n\nSeries 3, Week 6, Day 1\n\nEach week a group of four famous faces go toe to toe testing their general knowledge skills in a variety of fun trivia-based games.\n\nEvery day this week the celebrity contestants – Jay Blades, Shaun Keaveny, Rachel Parris and Jan Ravens - take on a series of quiz rounds selected by the host, quiz legend Richard Osman.\n A daily winner is declared following a quick-fire round at the end of each show as the scores are tallied across the week resulting in an overall champion being crowned on Friday.\n Will the winning stars opt for the much coveted House of Games dressing gown, or instead go for the must-have branded fondue set?\nFun, witty, and full of surprises, Richard’s cross-examination of the celebs over the course of a week provides an entertaining watch for all the family as the level of competitiveness and camaraderie grows.\n And of course, this warm, feel-good quiz is perfect for playing along with at home.\n\n-----\n\nSeries 3 Episode 26 (m000b8wx) (hd)",
                "thumbnails": {
                    "default": {
                        "url": "https://i.ytimg.com/vi/9KZ0euKnIak/default.jpg",
                        "width": 120,
                        "height": 90,
                    },
                    "medium": {
                        "url": "https://i.ytimg.com/vi/9KZ0euKnIak/mqdefault.jpg",
                        "width": 320,
                        "height": 180,
                    },
                    "high": {
                        "url": "https://i.ytimg.com/vi/9KZ0euKnIak/hqdefault.jpg",
                        "width": 480,
                        "height": 360,
                    },
                    "standard": {
                        "url": "https://i.ytimg.com/vi/9KZ0euKnIak/sddefault.jpg",
                        "width": 640,
                        "height": 480,
                    },
                    "maxres": {
                        "url": "https://i.ytimg.com/vi/9KZ0euKnIak/maxresdefault.jpg",
                        "width": 1280,
                        "height": 720,
                    },
                },
                "channelTitle": "Mundo",
                "categoryId": "24",
                "liveBroadcastContent": "none",
                "localized": {
                    "title": "Richard Osman's House of Games - S03E26 (11 Nov 2019)",
                    "description": "Jay Blades, Rachel Parris, Shaun Keaveny, Jan Ravens\n\nSeries 3, Week 6, Day 1\n\nEach week a group of four famous faces go toe to toe testing their general knowledge skills in a variety of fun trivia-based games.\n\nEvery day this week the celebrity contestants – Jay Blades, Shaun Keaveny, Rachel Parris and Jan Ravens - take on a series of quiz rounds selected by the host, quiz legend Richard Osman.\n A daily winner is declared following a quick-fire round at the end of each show as the scores are tallied across the week resulting in an overall champion being crowned on Friday.\n Will the winning stars opt for the much coveted House of Games dressing gown, or instead go for the must-have brJan Ravens - take on a series of quiz rounds selected by the host, quiz legend Richard Osman.\n A daily winner is declared following a quick-fire round at the end of each show as the scores are tallied across the week resulting in an overall champion being crowned on Friday.\n Will the winning stars opt for the much coveted House of Games dressing gown, or instead go for the must-have branded fondue set?\nFun, witty, and full of surprises, Richard’s cross-examination of the celebs over the course of a week provides an entertaining watch for all the family as the level of competitiveness and camaraderie grows.\n And of course, this warm, feel-good quiz is perfect for playing along with at home.\n\n-----\n\nSeries 3 Episode 26 (m000b8wx) (hd)",
                },
                "defaultAudioLanguage": "en-GB",
            },
        },
    ],
    "pageInfo": {"totalResults": 2, "resultsPerPage": 2},
}

mock_four_vid_responses = {
    "kind": "youtube#videoListResponse",
    "etag": "nwnKSrcYl-H7HW2QzWdgsqeKUvQ",
    "items": [
        {
            "kind": "youtube#video",
            "etag": "yKGN8XFPHRAEKWWXDam3_9H2E08",
            "id": "ynYsMu14BrA",
            "snippet": {
                "publishedAt": "2019-02-11T18:58:49Z",
                "channelId": "UC_OttpBEWWzSUlZbk5qmhSA",
                "title": "How To Pass As A Woman | Mia Mulder",
                "description": "What is passing? What does passing mean? How does it impact identity? \n\nThis video is about my own personal exploration about that term and what it means for me and how it makes me feel. My experiences are not universal but they are still my experiences. \n\nThis video is made from my perspective. I don't expect everyone to have a similar view on passing as me, and I think that's good. I don't want to make anyone feel like they *should* think about passing in any way. I just want to share my own perspective which I sometimes feel is overlooked in the greater conversation about passing, looks, appearance and identity. \n\nPlease don't read anything into this that I don't mean. If you have questions or anything you feel like I should clarify, please tell me in the comments. \n\nSarahs video on transitioning\nhttps://www.youtube.com/watch?v=3PClMhVAQWg\n\n------------\nPronouns: She/Her (Maybe?)\nInstagram: Mia_mulder\nTwitter: www.twitter.com/potatopolitics\nPatreon: www.patreon.com/MiaMulder\nOne Time Donations: www.ko-fi.com/miamulder\nwww.paypal.me/MiaMulder\n\n-------------\n\nReaders! Do You Read by Chris Zabriskie is licensed under a Creative Commons Attribution license (https://creativecommons.org/licenses/by/4.0/)\nSource: http://chriszabriskie.com/reappear/\nArtist: http://chriszabriskie.com/\n\nDirect to Video by Chris Zabriskie is licensed under a Creative Commons Attribution license (https://creativecommons.org/licenses/by/4.0/)\nSource: http://chriszabriskie.com/dtv/\nArtist: http://chriszabriskie.com/\n\nBrethren, Arise by Chris Zabriskie is licensed under a Creative Commons Attribution license (https://creativecommons.org/licenses/by/4.0/)\nSource: http://chriszabriskie.com/darkglow/\nArtist: http://chriszabriskie.com/",
                "thumbnails": {
                    "default": {
                        "url": "https://i.ytimg.com/vi/ynYsMu14BrA/default.jpg",
                        "width": 120,
                        "height": 90,
                    },
                    "medium": {
                        "url": "https://i.ytimg.com/vi/ynYsMu14BrA/mqdefault.jpg",
                        "width": 320,
                        "height": 180,
                    },
                    "high": {
                        "url": "https://i.ytimg.com/vi/ynYsMu14BrA/hqdefault.jpg",
                        "width": 480,
                        "height": 360,
                    },
                    "standard": {
                        "url": "https://i.ytimg.com/vi/ynYsMu14BrA/sddefault.jpg",
                        "width": 640,
                        "height": 480,
                    },
                },
                "channelTitle": "Mia Mulder",
                "tags": [
                    "identity",
                    "passing",
                    "woman",
                    "how to pass as a woman",
                    "how",
                    "to",
                    "pass",
                    "as",
                    "Mia Mulder",
                    "Mia",
                    "Mulder",
                    "trans",
                    "transgender",
                    "trans woman",
                    "transwoman",
                    "transition",
                    "cis",
                ],
                "categoryId": "22",
                "liveBroadcastContent": "none",
                "defaultLanguage": "en",
                "localized": {
                    "title": "How To Pass As A Woman | Mia Mulder",
                    "description": "What is passing? What does passing mean? How does it impact identity? \n\nThis video is about my own personal exploration about that term and what it means for me and how it makes me feel. My experiences are not universal but they are still my experiences. \n\nThis video is made from my perspective. I don't expect everyone to have a similar view on passing as me, and I think that's good. I don't want to make anyone feel like they *should* think about passing in any way. I just want to share my own perspective which I sometimes feel is overlooked in the greater conversation about passing, looks, appearance and identity. \n\nPlease don't read anything into this that I don't mean. If you have questions or anything you feel like I should clarify, please tell me in the comments. \n\nSarahs video on transitioning\nhttps://www.youtube.com/watch?v=3PClMhVAQWg\n\n------------\nPronouns: She/Her (Maybe?)\nInstagram: Mia_mulder\nTwitter: www.twitter.com/potatopolitics\nPatreon: www.patreon.com/MiaMulder\nOne Time Donations: www.ko-fi.com/miamulder\nwww.paypal.me/MiaMulder\n\n-------------\n\nReaders! Do You Read by Chris Zabriskie is licensed under a Creative Commons Attribution license (https://creativecommons.org/licenses/by/4.0/)\nSource: http://chriszabriskie.com/reappear/\nArtist: http://chriszabriskie.com/\n\nDirect to Video by Chris Zabriskie is licensed under a Creative Commons Attribution license (https://creativecommons.org/licenses/by/4.0/)\nSource: http://chriszabriskie.com/dtv/\nArtist: http://chriszabriskie.com/\n\nBrethren, Arise by Chris Zabriskie is licensed under a Creative Commons Attribution license (https://creativecommons.org/licenses/by/4.0/)\nSource: http://chriszabriskie.com/darkglow/\nArtist: http://chriszabriskie.com/",
                },
                "defaultAudioLanguage": "en",
            },
        },
        {
            "kind": "youtube#video",
            "etag": "ouBMu6XzV5D3XMC6HTbCiHNjL90",
            "id": "9KZ0euKnIak",
            "snippet": {
                "publishedAt": "2021-07-12T17:15:19Z",
                "channelId": "UCq_ZoGyeCb-1nUCD9z8Fzcg",
                "title": "Richard Osman's House of Games - S03E26 (11 Nov 2019)",
                "description": "Jay Blades, Rachel Parris, Shaun Keaveny, Jan Ravens\n\nSeries 3, Week 6, Day 1\n\nEach week a group of four famous faces go toe to toe testing their general knowledge skills in a variety of fun trivia-based games.\n\nEvery day this week the celebrity contestants – Jay Blades, Shaun Keaveny, Rachel Parris and Jan Ravens - take on a series of quiz rounds selected by the host, quiz legend Richard Osman.\n A daily winner is declared following a quick-fire round at the end of each show as the scores are tallied across the week resulting in an overall champion being crowned on Friday.\n Will the winning stars opt for the much coveted House of Games dressing gown, or instead go for the must-have branded fondue set?\nFun, witty, and full of surprises, Richard’s cross-examination of the celebs over the course of a week provides an entertaining watch for all the family as the level of competitiveness and camaraderie grows.\n And of course, this warm, feel-good quiz is perfect for playing along with at home.\n\n-----\n\nSeries 3 Episode 26 (m000b8wx) (hd)",
                "thumbnails": {
                    "default": {
                        "url": "https://i.ytimg.com/vi/9KZ0euKnIak/default.jpg",
                        "width": 120,
                        "height": 90,
                    },
                    "medium": {
                        "url": "https://i.ytimg.com/vi/9KZ0euKnIak/mqdefault.jpg",
                        "width": 320,
                        "height": 180,
                    },
                    "high": {
                        "url": "https://i.ytimg.com/vi/9KZ0euKnIak/hqdefault.jpg",
                        "width": 480,
                        "height": 360,
                    },
                    "standard": {
                        "url": "https://i.ytimg.com/vi/9KZ0euKnIak/sddefault.jpg",
                        "width": 640,
                        "height": 480,
                    },
                    "maxres": {
                        "url": "https://i.ytimg.com/vi/9KZ0euKnIak/maxresdefault.jpg",
                        "width": 1280,
                        "height": 720,
                    },
                },
                "channelTitle": "Mundo",
                "categoryId": "24",
                "liveBroadcastContent": "none",
                "localized": {
                    "title": "Richard Osman's House of Games - S03E26 (11 Nov 2019)",
                    "description": "Jay Blades, Rachel Parris, Shaun Keaveny, Jan Ravens\n\nSeries 3, Week 6, Day 1\n\nEach week a group of four famous faces go toe to toe testing their general knowledge skills in a variety of fun trivia-based games.\n\nEvery day this week the celebrity contestants – Jay Blades, Shaun Keaveny, Rachel Parris and Jan Ravens - take on a series of quiz rounds selected by the host, quiz legend Richard Osman.\n A daily winner is declared following a quick-fire round at the end of each show as the scores are tallied across the week resulting in an overall champion being crowned on Friday.\n Will the winning stars opt for the much coveted House of Games dressing gown, or instead go for the must-have branded fondue set?\nFun, witty, and full of surprises, Richard’s cross-examination of the celebs over the course of a week provides an entertaining watch for all the family as the level of competitiveness and camaraderie grows.\n And of course, this warm, feel-good quiz is perfect for playing along with at home.\n\n-----\n\nSeries 3 Episode 26 (m000b8wx) (hd)",
                },
                "defaultAudioLanguage": "en-GB",
            },
        },
        {
            "kind": "youtube#video",
            "etag": "8lFQOVTWehjTSg8PEx8Hc4JhcIs",
            "id": "ea6NieliCIU",
            "snippet": {
                "publishedAt": "2023-08-26T01:00:00Z",
                "channelId": "UCWOA1ZGywLbqmigxE4Qlvuw",
                "title": "ONE PIECE | Eiichiro Oda Meets Iñaki Godoy | Netflix",
                "description": '"I can’t imagine anyone else but you" 😭 Come along with us on a dream visit to the studio of the legendary Eiichiro Oda. #OnePieceNetflix\n\nSUBSCRIBE: http://bit.ly/29qBUt7\n\nAbout Netflix:\nNetflix is one of the world\'s leading entertainment services with over 238 million paid memberships in over 190 countries enjoying TV series, films and games across a wide variety of genres and languages. Members can play, pause and resume watching as much as they want, anytime, anywhere, and can change their plans at any time.\n\nONE PIECE | Eiichiro Oda Meets Iñaki Godoy | Netflix\nhttps://www.youtube.com/@Netflix\n\nWith his straw hat and ragtag crew, young pirate Monkey D. Luffy goes on an epic voyage for treasure in this live-action adaptation of the popular manga.',
                "thumbnails": {
                    "default": {
                        "url": "https://i.ytimg.com/vi/ea6NieliCIU/default.jpg",
                        "width": 120,
                        "height": 90,
                    },
                    "medium": {
                        "url": "https://i.ytimg.com/vi/ea6NieliCIU/mqdefault.jpg",
                        "width": 320,
                        "height": 180,
                    },
                    "high": {
                        "url": "https://i.ytimg.com/vi/ea6NieliCIU/hqdefault.jpg",
                        "width": 480,
                        "height": 360,
                    },
                    "standard": {
                        "url": "https://i.ytimg.com/vi/ea6NieliCIU/sddefault.jpg",
                        "width": 640,
                        "height": 480,
                    },
                    "maxres": {
                        "url": "https://i.ytimg.com/vi/ea6NieliCIU/maxresdefault.jpg",
                        "width": 1280,
                        "height": 720,
                    },
                },
                "channelTitle": "Netflix",
                "tags": [
                    "Adventure",
                    "Akemi Okamura",
                    "Alvida",
                    "Anime",
                    "Arlong",
                    "Buggy",
                    "Eiichiro Oda",
                    "Emily Rudd",
                    "Going Merry",
                    "Gum Gum",
                    "Iñaki Godoy",
                    "Jacob Romero Gibson",
                    "Kuro",
                    "Live Action",
                    "Luffy",
                    "Mackenyu",
                    "Manga",
                    "Mihawk",
                    "Monkey D. Luffy",
                    "Nami",
                    "Netflix",
                    "ONE PIECE",
                    "One Piece Live Action Trailer",
                    "One Piece Netflix",
                    "Pirates",
                    "Roronoa Zoro",
                    "Sanji",
                    "Sogeking",
                    "Straw Hat",
                    "Stretch",
                    "Stretchy",
                    "Taz Skylar",
                    "Trailer",
                    "Usopp",
                    "Vinsmoke Sanji",
                    "Zoro",
                ],
                "categoryId": "24",
                "liveBroadcastContent": "none",
                "localized": {
                    "title": "ONE PIECE | Eiichiro Oda Meets Iñaki Godoy | Netflix",
                    "description": '"I can’t imagine anyone else but you" 😭 Come along with us on a dream visit to the studio of the legendary Eiichiro Oda. #OnePieceNetflix\n\nSUBSCRIBE: http://bit.ly/29qBUt7\n\nAbout Netflix:\nNetflix is one of the world\'s leading entertainment services with over 238 million paid memberships in over 190 countries enjoying TV series, films and games across a wide variety of genres and languages. Members can play, pause and resume watching as much as they want, anytime, anywhere, and can change their plans at any time.\n\nONE PIECE | Eiichiro Oda Meets Iñaki Godoy | Netflix\nhttps://www.youtube.com/@Netflix\n\nWith his straw hat and ragtag crew, young pirate Monkey D. Luffy goes on an epic voyage for treasure in this live-action adaptation of the popular manga.',
                },
                "defaultAudioLanguage": "en-US",
            },
        },
        {
            "kind": "youtube#video",
            "etag": "yqi7D7Ne9JIvEjYRx2mjXKsnPtw",
            "id": "SH47tcY8ceU",
            "snippet": {
                "publishedAt": "2023-08-26T16:00:30Z",
                "channelId": "UCLuI5IP4nBr82VxClxp7Teg",
                "title": "The Bizarre Ending of Riverdale",
                "description": 'SONG: "If You Know" by FSN\nhttps://open.spotify.com/track/15tSP0n051MaRUmg8a3sGG?si=3efd2df87f264fd8\n\nFOLLOW ME\nInstagram: https://www.instagram.com/friendlyspaceninja\nSpotify: https://open.spotify.com/artist/5rjWIN0rc5oEksE94qQMCm?si=czhQ5GqxTmiiOH5lkrKebA\nTikTok: @friendlyspaceninja\n\nTimestamps\n0:00 Intro\n2:50 Season 7\n19:53 Episode 19\n24:45 The Finale\n42:23 Final Conclusion',
                "thumbnails": {
                    "default": {
                        "url": "https://i.ytimg.com/vi/SH47tcY8ceU/default.jpg",
                        "width": 120,
                        "height": 90,
                    },
                    "medium": {
                        "url": "https://i.ytimg.com/vi/SH47tcY8ceU/mqdefault.jpg",
                        "width": 320,
                        "height": 180,
                    },
                    "high": {
                        "url": "https://i.ytimg.com/vi/SH47tcY8ceU/hqdefault.jpg",
                        "width": 480,
                        "height": 360,
                    },
                    "standard": {
                        "url": "https://i.ytimg.com/vi/SH47tcY8ceU/sddefault.jpg",
                        "width": 640,
                        "height": 480,
                    },
                    "maxres": {
                        "url": "https://i.ytimg.com/vi/SH47tcY8ceU/maxresdefault.jpg",
                        "width": 1280,
                        "height": 720,
                    },
                },
                "channelTitle": "Friendly Space Ninja",
                "categoryId": "24",
                "liveBroadcastContent": "none",
                "localized": {
                    "title": "The Bizarre Ending of Riverdale",
                    "description": 'SONG: "If You Know" by FSN\nhttps://open.spotify.com/track/15tSP0n051MaRUmg8a3sGG?si=3efd2df87f264fd8\n\nFOLLOW ME\nInstagram: https://www.instagram.com/friendlyspaceninja\nSpotify: https://open.spotify.com/artist/5rjWIN0rc5oEksE94qQMCm?si=czhQ5GqxTmiiOH5lkrKebA\nTikTok: @friendlyspaceninja\n\nTimestamps\n0:00 Intro\n2:50 Season 7\n19:53 Episode 19\n24:45 The Finale\n42:23 Final Conclusion',
                },
                "defaultAudioLanguage": "en",
            },
        },
    ],
    "pageInfo": {"totalResults": 4, "resultsPerPage": 4},
}

# All parts
mock_one_vid_responses = {
    "kind": "youtube#videoListResponse",
    "etag": "r1efCSRvQTW001PNn3eet8lXmRU",
    "items": [
        {
            "kind": "youtube#video",
            "etag": "n5P2MAjwBU0_PnZbZxPqkDqp0C8",
            "id": "Ks-_Mh1QhMc",
            "snippet": {
                "publishedAt": "2012-10-01T15:27:35Z",
                "channelId": "UCAuUUnT6oDeKwE6v1NGQxug",
                "title": "Your body language may shape who you are | Amy Cuddy",
                "description": "Body language affects how others see us, but it may also change how we see ourselves. Social psychologist Amy Cuddy argues that \"power posing\" -- standing in a posture of confidence, even when we don't feel confident -- can boost feelings of confidence, and might have an impact on our chances for success. (Note: Some of the findings presented in this talk have been referenced in an ongoing debate among social scientists about robustness and reproducibility. Read Amy Cuddy's response here: http://ideas.ted.com/inside-the-debate-about-power-posing-a-q-a-with-amy-cuddy/)\n\nGet TED Talks recommended just for you! Learn more at https://www.ted.com/signup.\n\nThe TED Talks channel features the best talks and performances from the TED Conference, where the world's leading thinkers and doers give the talk of their lives in 18 minutes (or less). Look for talks on Technology, Entertainment and Design -- plus science, business, global issues, the arts and more.\n\nFollow TED on Twitter: http://www.twitter.com/TEDTalks\nLike TED on Facebook: https://www.facebook.com/TED\n\nSubscribe to our channel: https://www.youtube.com/TED",
                "thumbnails": {
                    "default": {
                        "url": "https://i.ytimg.com/vi/Ks-_Mh1QhMc/default.jpg",
                        "width": 120,
                        "height": 90,
                    },
                    "medium": {
                        "url": "https://i.ytimg.com/vi/Ks-_Mh1QhMc/mqdefault.jpg",
                        "width": 320,
                        "height": 180,
                    },
                    "high": {
                        "url": "https://i.ytimg.com/vi/Ks-_Mh1QhMc/hqdefault.jpg",
                        "width": 480,
                        "height": 360,
                    },
                    "standard": {
                        "url": "https://i.ytimg.com/vi/Ks-_Mh1QhMc/sddefault.jpg",
                        "width": 640,
                        "height": 480,
                    },
                    "maxres": {
                        "url": "https://i.ytimg.com/vi/Ks-_Mh1QhMc/maxresdefault.jpg",
                        "width": 1280,
                        "height": 720,
                    },
                },
                "channelTitle": "TED",
                "tags": [
                    "Amy Cuddy",
                    "TED",
                    "TEDTalk",
                    "TEDTalks",
                    "TED Talk",
                    "TED Talks",
                    "TEDGlobal",
                    "brain",
                    "business",
                    "psychology",
                    "self",
                    "success",
                ],
                "categoryId": "22",
                "liveBroadcastContent": "none",
                "defaultLanguage": "en",
                "localized": {
                    "title": "Your body language may shape who you are | Amy Cuddy",
                    "description": "Body language affects how others see us, but it may also change how we see ourselves. Social psychologist Amy Cuddy argues that \"power posing\" -- standing in a posture of confidence, even when we don't feel confident -- can boost feelings of confidence, and might have an impact on our chances for success. (Note: Some of the findings presented in this talk have been referenced in an ongoing debate among social scientists about robustness and reproducibility. Read Amy Cuddy's response here: http://ideas.ted.com/inside-the-debate-about-power-posing-a-q-a-with-amy-cuddy/)\n\nGet TED Talks recommended just for you! Learn more at https://www.ted.com/signup.\n\nThe TED Talks channel features the best talks and performances from the TED Conference, where the world's leading thinkers and doers give the talk of their lives in 18 minutes (or less). Look for talks on Technology, Entertainment and Design -- plus science, business, global issues, the arts and more.\n\nFollow TED on Twitter: http://www.twitter.com/TEDTalks\nLike TED on Facebook: https://www.facebook.com/TED\n\nSubscribe to our channel: https://www.youtube.com/TED",
                },
                "defaultAudioLanguage": "en",
            },
            "contentDetails": {
                "duration": "PT21M3S",
                "dimension": "2d",
                "definition": "hd",
                "caption": "true",
                "licensedContent": "true",
                "contentRating": {},
                "projection": "rectangular",
            },
            "statistics": {
                "viewCount": "23870918",
                "likeCount": "404237",
                "favoriteCount": "0",
                "commentCount": "9585",
            },
        }
    ],
    "pageInfo": {"totalResults": 1, "resultsPerPage": 1},
}

## Videos IDs
# 5 vids
short_vid_ID_lst = [
    "ynYsMu14BrA",
    "9KZ0euKnIak",
    "ea6NieliCIU",
    "SH47tcY8ceU",
    "dj5SAmfqZr4",
]
# 50 vids
long_vid_ID_lst = [
    "r980Y7QtcVQ",
    "QiJZ6aWt3X4",
    "brsI6OPZrPg",
    "mdCPAuW6JPU",
    "fMTkMZv4gxo",
    "au5QceeWFUY",
    "oom2NTgYQ38",
    "B4bY5F6U3q8",
    "AMzxwht8Pwk",
    "tM2Fg_U_HMc",
    "w-nFu-qWKGc",
    "6kxwG5OTkGA",
    "K9eq6u03HiM",
    "vQgnPl3tR5k",
    "qJ6Q4W9EnRE",
    "y5UJhRb7A3M",
    "Otiw3jezBkE",
    "gumiqNtc7eY",
    "4eACxGyVgqc",
    "Y15hyQVhgl8",
    "llm63k3ZrXQ",
    "x5tm6T288Mo",
    "iRDYJVSJu4A",
    "93Q1VNduXUQ",
    "XxGXBLpENpg",
    "JO5Wl_xtKcQ",
    "-ZwnzB27Yk4",
    "xp8RNBGUKIE",
    "WC7SZca8E6M",
    "GlM11o_0x-M",
    "WISSnt4zwj4",
    "F3Sk7GIX-0k",
    "GntzNnZQmKQ",
    "ZDlv7iXe3bk",
    "yeTq09b0UcQ",
    "o1TmLyHLhAk",
    "Vb9smBoi918",
    "5VVDItZVlEY",
    "dlQMpxsnh3s",
    "DcfP7Yn13EI",
    "2bi2Sro1zIE",
    "-XMz7ayx7I4",
    "dI2oRROlLqg",
    "YYETbX1Va1s",
    "LZlJrjcErCA",
    "DJx2zwB_49M",
    "wO95xZC7pJo",
    "eQ_7YFyHCQg",
    "50rrGNgAZRo",
    "NI8C4rG3LsE",
]
# More than 50 vids
very_long_vid_ID_lst = [
    "r980Y7QtcVQ",
    "QiJZ6aWt3X4",
    "brsI6OPZrPg",
    "mdCPAuW6JPU",
    "fMTkMZv4gxo",
    "au5QceeWFUY",
    "oom2NTgYQ38",
    "B4bY5F6U3q8",
    "AMzxwht8Pwk",
    "tM2Fg_U_HMc",
    "w-nFu-qWKGc",
    "6kxwG5OTkGA",
    "K9eq6u03HiM",
    "vQgnPl3tR5k",
    "qJ6Q4W9EnRE",
    "y5UJhRb7A3M",
    "Otiw3jezBkE",
    "gumiqNtc7eY",
    "4eACxGyVgqc",
    "Y15hyQVhgl8",
    "llm63k3ZrXQ",
    "x5tm6T288Mo",
    "iRDYJVSJu4A",
    "93Q1VNduXUQ",
    "XxGXBLpENpg",
    "JO5Wl_xtKcQ",
    "-ZwnzB27Yk4",
    "xp8RNBGUKIE",
    "WC7SZca8E6M",
    "GlM11o_0x-M",
    "WISSnt4zwj4",
    "F3Sk7GIX-0k",
    "GntzNnZQmKQ",
    "ZDlv7iXe3bk",
    "yeTq09b0UcQ",
    "o1TmLyHLhAk",
    "Vb9smBoi918",
    "5VVDItZVlEY",
    "dlQMpxsnh3s",
    "DcfP7Yn13EI",
    "2bi2Sro1zIE",
    "-XMz7ayx7I4",
    "dI2oRROlLqg",
    "YYETbX1Va1s",
    "LZlJrjcErCA",
    "DJx2zwB_49M",
    "wO95xZC7pJo",
    "eQ_7YFyHCQg",
    "50rrGNgAZRo",
    "NI8C4rG3LsE",
    "X8R6HYy77bY",
    "lJZ82GxBtuw",
    "DthSIEop8Rk",
    "egD3R-zIlOg",
    "EGn9Bg1peIE",
    "daoIPb6pbP0",
    "C3uYWjQG4dI",
    "Z88HG1JRYtQ",
    "ndovKIJzGxk",
    "07V2BlgkrkY",
    "7VDmRgR-VdA",
    "iee2Cc-7t58",
    "wwjydxSiWDw",
    "Tfgpr0GHROg",
    "I7DOlav20hE",
    "1vM3QYTrQro",
    "LzqDBYFmcBQ",
    "nXNDsjZ3ilc",
    "I79XZOg5cfc",
    "Yt7MoSzalOI",
    "-8EMkVyQgCQ",
    "1k_PIv7XXtk",
    "tXEt9b0dNxM",
    "-SZGSms3WCs",
    "fQABBkGR6AE",
    "EU8uoZbUMYE",
    "gQun0aclzr8",
    "_HhMds5GgFY",
    "4o9lwOxlsS0",
    "s84DN2fByFw",
    "9quOJ93UpnQ",
    "vcSkoOdvFyA",
    "YYuIIW8RQZo",
    "ceX9nophCgw",
    "1DTS2rA71cw",
    "oCtxP3a8lkI",
    "gfSdPHWkTcE",
    "I4WxAE7beE0",
    "nkQxJ8O9f-U",
    "58wrBos8TBc",
    "uMTwGUC1Z5Y",
    "IOt88WPD0vk",
    "NPrdj7mk_Zw",
    "LoiHp6wULxM",
    "FDBSvelG2Yk",
    "xGPcjMP5M80",
    "VW_-P60Wtw8",
    "D4khkFWs0VI",
    "MzwLeKpO5GU",
    "HmghoyVSkJM",
    "q79QM7NKEd4",
    "fnc95Mv5MXA",
    "5HW_j9tCRKI",
    "s6Ch8Q_yXsY",
    "xC0ndhhMrhA",
    "NOG1GHdH6LM",
    "KP14hmZV0Gg",
    "Pxqv5nEXL1c",
    "QwD275rVhkE",
    "hrxcXxY_whM",
    "eL02-Z8ugYk",
    "XC-JMDiSDPk",
    "KH2dmV2LtQo",
    "zSdv9otF-4Y",
    "gW9k0PI0JhY",
    "P8y2rwbH6SM",
    "IAJu0-HMJzc",
    "tA4LPHdX__Q",
    "VMyKlMRpQ88",
    "YeVGZb86Drs",
    "NCid7XcZmfc",
    "DCXIaWQBnpY",
    "XR2tVZeQO5Y",
    "NGQp0ovv3s8",
    "5MMk-DPh-z0",
    "-EhuZuObO8U",
    "QV9U1zUSI_c",
    "fQ891FzNUqs",
    "orINxWYXAts",
    "-uPZN0gkM8U",
    "W2N7o8vvlrA",
    "oGwbC7x5IHA",
    "7jp4gcYcUwk",
    "Z_P1zrVqSp4",
    "eAqPTZUtwRg",
    "WT9xLAOcSIc",
    "fN0E3ovI8Oo",
    "YsA7Yow_YOM",
    "Jyn4KNBenw0",
    "7jOnhl0WB5Y",
    "bOwsXOHMMfU",
    "xwWM2WiUhnk",
    "tmgA-yPztY4",
    "zZx6aLS9zA4",
    "_kS2aWEsT0M",
    "7VuSr8YV3nY",
    "ZhfmVxfN300",
]

## Videos dict
mock_very_long_videos = {
    "r980Y7QtcVQ": {
        "upload day": "2023-08-08",
        "channel name": "Adequate ASMR",
        "upload playlist": "UU_4CsQXbCI1LV7dug83qL8A",
        "to add": False,
        "title": "ASMR Inaudible, Unintelligible, and Kisses",
        "duration": 1549.0,
        "is short": False,
    },
    "QiJZ6aWt3X4": {
        "upload day": "2023-08-04",
        "channel name": "Adequate ASMR",
        "upload playlist": "UU_4CsQXbCI1LV7dug83qL8A",
        "to add": False,
        "title": "Hand and Mouth Sounds ASMR",
        "duration": 1061.0,
        "is short": False,
    },
    "brsI6OPZrPg": {
        "upload day": "2022-10-14",
        "channel name": "Adequate ASMR",
        "upload playlist": "UU_4CsQXbCI1LV7dug83qL8A",
        "to add": False,
        "title": "Fast, intense mouth sounds, hand sounds, inaudible/unintelligible ASMR",
        "duration": 1059.0,
        "is short": False,
    },
    "mdCPAuW6JPU": {
        "upload day": "2022-05-19",
        "channel name": "Adequate ASMR",
        "upload playlist": "UU_4CsQXbCI1LV7dug83qL8A",
        "to add": False,
        "title": "Fluffy Scalp Massage ASMR",
        "duration": 1228.0,
        "is short": False,
    },
    "fMTkMZv4gxo": {
        "upload day": "2022-05-12",
        "channel name": "Adequate ASMR",
        "upload playlist": "UU_4CsQXbCI1LV7dug83qL8A",
        "to add": False,
        "title": "Tongue, Teeth, and Mouth Sounds ASMR",
        "duration": 2145.0,
        "is short": False,
    },
    "wf5Vp8Wiryw": {
        "upload day": "2023-09-27",
        "channel name": "Alinéa ASMR",
        "upload playlist": "UUf3VwNBuriywg4oge0e38DA",
        "to add": False,
        "title": "ASMR | Mes abonnés font de l'ASMR ♡",
        "duration": 653.0,
        "is short": False,
    },
    "ZB0-eq4TF9k": {
        "upload day": "2023-09-17",
        "channel name": "Alinéa ASMR",
        "upload playlist": "UUf3VwNBuriywg4oge0e38DA",
        "to add": False,
        "title": "J'ASMRise un abonné (on a trouvé ça trop bien ✨)",
        "duration": 1985.0,
        "is short": False,
    },
    "MWtAC-ndLy4": {
        "upload day": "2023-09-11",
        "channel name": "Alinéa ASMR",
        "upload playlist": "UUf3VwNBuriywg4oge0e38DA",
        "to add": False,
        "title": "Ce qui se passe sur Twitch... 🤷\u200d♀️ |  BEST OF #01",
        "duration": 651.0,
        "is short": False,
    },
    "au5QceeWFUY": {
        "upload day": "2023-09-03",
        "channel name": "Alinéa ASMR",
        "uupload playlist": "UUf3VwNBuriywg4oge0e38DA",
        "to add": False,
        "title": "ASMR | 26 min de tapping doux et réconfortant ♡",
        "duration": 1561.0,
        "is short": False,
    },
    "oom2NTgYQ38": {
        "upload day": "2023-08-27",
        "channel name": "Alinéa ASMR",
        "upload playlist": "UUf3VwNBuriywg4oge0e38DA",
        "to add": False,
        "title": "ASMR | Papouilles sur ton visage ✨",
        "duration": 2417.0,
        "is short": False,
    },
    "B46GYUSaIVQ": {
        "upload day": "2023-10-08",
        "channel name": "ASMR con Kiki",
        "upload playlist": "UUR9ehrySGCcxFNg8gCA2rsQ",
        "to add": False,
        "title": "ASMR👶Q & A con mi BEBÉ👶 ✨PREGUNTAS Y RESPUESTAS 💚 Episodio 1",
        "duration": 1451.0,
        "is short": False,
    },
    "DMnpwWbfTAs": {
        "upload day": "2023-09-15",
        "channel name": "ASMR con Kiki",
        "upload playlist": "UUR9ehrySGCcxFNg8gCA2rsQ",
        "to add": False,
        "title": "ASMR 1h Colección de mis MEJORES Sesiones de SONIDOS 💤(｡-‿-｡)💤",
        "duration": 4403.0,
        "is short": False,
    },
    "w-nFu-qWKGc": {
        "upload day": "2023-07-02",
        "channel name": "ASMR con Kiki",
        "upload playlist": "UUR9ehrySGCcxFNg8gCA2rsQ",
        "to add": False,
        "title": "ASMR LIMPIEZA DE OÍDOS (Roleplay en español) BINAURAL 👂🏼✨ Con Sesión de Sonidos para RELAJARSE",
        "duration": 1295.0,
        "is short": False,
    },
    "6kxwG5OTkGA": {
        "upload day": "2023-06-18",
        "channel name": "ASMR con Kiki",
        "upload playlist": "UUR9ehrySGCcxFNg8gCA2rsQ",
        "to add": False,
        "title": "🛠️ASMR RP ARREGLANDOTE 🤖(Eres un ROBOT) Atención Personal Sci-Fi",
        "duration": 1179.0,
        "is short": False,
    },
    "K9eq6u03HiM": {
        "upload day": "2023-06-11",
        "channel name": "ASMR con Kiki",
        "upload playlist": "UUR9ehrySGCcxFNg8gCA2rsQ",
        "to add": False,
        "title": "ASMR DOCTORA KIKI👓EXAMEN de tu VISIÓN MUY DETALLADO y relajación de tus OJOS",
        "duration": 1311.0,
        "is short": False,
    },
    "uwjC-WcO-AA": {
        "upload day": "2023-10-10",
        "channel name": "ASMR Glow",
        "upload playlist": "UUFmL725KKPx2URVPvH3Gp8w",
        "to add": False,
        "title": "4K ASMR: Goodnight Kisses & Sweet Comfort (sshh..)",
        "duration": 1134.0,
        "is short": False,
    },
    "enNcfkvyeQU": {
        "upload day": "2023-10-08",
        "channel name": "ASMR Glow",
        "upload playlist": "UUFmL725KKPx2URVPvH3Gp8w",
        "to add": False,
        "title": "Massaging Your Stress Away #shorts #asmr #personalattention",
        "duration": 60.0,
        "is short": True,
    },
    "kR8RBwcCJDQ": {
        "upload day": "2023-10-06",
        "channel name": "ASMR Glow",
        "upload playlist": "UUFmL725KKPx2URVPvH3Gp8w",
        "to add": False,
        "title": "4K ASMR: Answering Your Assumptions About Me...(page turning, writing...)",
        "duration": 2570.0,
        "is short": False,
    },
    "bFv6Xh8mGIY": {
        "upload day": "2023-10-03",
        "channel name": "ASMR Glow",
        "upload playlist": "UUFmL725KKPx2URVPvH3Gp8w",
        "to add": False,
        "title": "4K ASMR: Analysing your face with unintelligible/mouth sounds",
        "duration": 983.0,
        "is short": False,
    },
    "CcMb09OIVgQ": {
        "upload day": "2023-10-01",
        "channel name": "ASMR Glow",
        "upload playlist": "UUFmL725KKPx2URVPvH3Gp8w",
        "to add": False,
        "title": "ASMR Glow 1h live stream! I wanna see ya!",
        "duration": 5010.0,
        "is short": False,
    },
    "llm63k3ZrXQ": {
        "upload day": "2022-05-18",
        "channel name": "ASMR Lauren",
        "upload playlist": "UU8ACo6o9WRTYOrMVfXfhFpA",
        "to add": False,
        "title": "ASMR Microphone Triggers (Scratching, Tapping, Cupping, Things on the mic)",
        "duration": 1412.0,
        "is short": False,
    },
    "x5tm6T288Mo": {
        "upload day": "2022-05-13",
        "channel name": "ASMR Lauren",
        "upload playlist": "UU8ACo6o9WRTYOrMVfXfhFpA",
        "to add": False,
        "title": "ASMR Random triggers for tingle immunity 🥰✨",
        "duration": 1335.0,
        "is short": False,
    },
    "iRDYJVSJu4A": {
        "upload day": "2022-01-16",
        "channel name": "ASMR Lauren",
        "upload playlist": "UU8ACo6o9WRTYOrMVfXfhFpA",
        "to add": False,
        "title": "ASMR New fast random triggers! ✨",
        "duration": 1276.0,
        "is short": False,
    },
    "93Q1VNduXUQ": {
        "upload day": "2021-10-23",
        "channel name": "ASMR Lauren",
        "upload playlist": "UU8ACo6o9WRTYOrMVfXfhFpA",
        "to add": False,
        "title": "ASMR Fast, Random and Up Close, Slightly soft spoken!",
        "duration": 759.0,
        "is short": False,
    },
    "XxGXBLpENpg": {
        "upload day": "2021-10-23",
        "channel name": "ASMR Lauren",
        "upload playlist": "UU8ACo6o9WRTYOrMVfXfhFpA",
        "to add": False,
        "title": "ASMR Fast and Aggressive LoFi 😊",
        "duration": 726.0,
        "is short": False,
    },
    "JO5Wl_xtKcQ": {
        "upload day": "2023-06-24",
        "channel name": "ASMR with Kiki",
        "upload playlist": "UUM740JWRTRDnSumg65flK2Q",
        "to add": False,
        "title": "ASMR Sleep Clinic  RP   Pillow Fitting measuring, tucking you in ft Zamat Sleep Inc.",
        "duration": 1565.0,
        "is short": False,
    },
    "-ZwnzB27Yk4": {
        "upload day": "2023-05-26",
        "channel name": "ASMR with Kiki",
        "upload playlist": "UUM740JWRTRDnSumg65flK2Q",
        "to add": False,
        "title": "ASMR Kiki on Patreon",
        "duration": 16.0,
        "is short": True,
    },
    "xp8RNBGUKIE": {
        "upload day": "2023-05-26",
        "channel name": "ASMR with Kiki",
        "upload playlist": "UUM740JWRTRDnSumg65flK2Q",
        "to add": False,
        "title": "ASMR whispered & soft spoken chit chat",
        "duration": 16.0,
        "is short": True,
    },
    "WC7SZca8E6M": {
        "upload day": "2023-05-05",
        "channel name": "ASMR with Kiki",
        "upload playlist": "UUM740JWRTRDnSumg65flK2Q",
        "to add": False,
        "title": "ASMR ESAME dei NERVI CRANICI per DORMIRE 💙(SOFT SPOKEN)",
        "duration": 1098.0,
        "is short": False,
    },
    "GlM11o_0x-M": {
        "upload day": "2023-04-19",
        "channel name": "ASMR with Kiki",
        "upload playlist": "UUM740JWRTRDnSumg65flK2Q",
        "to add": False,
        "title": "ASMR removing STONES from your EARS 🔮💎👂 with BINAURAL SOUNDSCAPE",
        "duration": 1415.0,
        "is short": False,
    },
    "kd6p7Hb_9Ko": {
        "upload day": "2023-10-11",
        "channel name": "asmr zeitgeist",
        "upload playlist": "UUzGEGjOCbgv9z9SF71QyI7g",
        "to add": True,
        "title": "ASMR 1000+ Triggers for People with ZERO Attention Span feat. Toshi the Tascam (No Talking)",
        "duration": 5971.0,
        "is short": False,
    },
    "S_XyQAEaHc8": {
        "upload day": "2023-10-04",
        "channel name": "asmr zeitgeist",
        "upload playlist": "UUzGEGjOCbgv9z9SF71QyI7g",
        "to add": False,
        "title": "The Fluffiest ASMR for Your Ears!  #asmr #tingles #shorts",
        "duration": 45.0,
        "is short": True,
    },
    "Y6ZDcVzNpCg": {
        "upload day": "2023-09-25",
        "channel name": "asmr zeitgeist",
        "upload playlist": "UUzGEGjOCbgv9z9SF71QyI7g",
        "to add": False,
        "title": "Soft & Fluffy ASMR for ULTIMATE Sleep! Tingle and Relax to the Most Gentle Triggers for Your Ears",
        "duration": 11820.0,
        "is short": False,
    },
    "4qpJ9VnHNQ8": {
        "upload day": "2023-09-15",
        "channel name": "asmr zeitgeist",
        "upload playlist": "UUzGEGjOCbgv9z9SF71QyI7g",
        "to add": False,
        "title": "LIQUID ASMR in Your Ears!! 💧 Strong Tingles & Deep Sleep #asmr #tingles #shorts",
        "duration": 44.0,
        "is short": True,
    },
    "H2qcEIp-_q0": {
        "upload day": "2023-09-11",
        "channel name": "asmr zeitgeist",
        "upload playlist": "UUzGEGjOCbgv9z9SF71QyI7g",
        "to add": False,
        "title": "LIQUID ASMR Right in Your Ears! The Tingliest Liquid Triggers for Sleep and Relaxation (No Talking)",
        "duration": 11577.0,
        "is short": False,
    },
    "5nTPd7tzUuk": {
        "upload day": "2023-10-12",
        "channel name": "ASMR_Divinity",
        "upload playlist": "UU_n9r4yRVXusIa6Cabl4wDw",
        "to add": False,
        "title": "ASMR | deep mic scratching & bassy ear blowing - no talking",
        "duration": 1221.0,
        "is short": False,
    },
    "woTNmjJqVKg": {
        "upload day": "2023-10-10",
        "channel name": "ASMR_Divinity",
        "upload playlist": "UU_n9r4yRVXusIa6Cabl4wDw",
        "to add": False,
        "title": "ASMR | fluffy mic & whispered ramble - blue yeti",
        "duration": 1497.0,
        "is short": False,
    },
    "lTyqvL-K83U": {
        "upload day": "2023-10-08",
        "channel name": "ASMR_Divinity",
        "upload playlist": "UU_n9r4yRVXusIa6Cabl4wDw",
        "to add": False,
        "title": "ASMR | 3 HOURS Wind Mic Blowing & Rain Sponge Sounds for Sleep - No Talking",
        "duration": 11313.0,
        "is short": False,
    },
    "VzaE6CkSkGk": {
        "upload day": "2023-10-06",
        "channel name": "ASMR_Divinity",
        "upload playlist": "UU_n9r4yRVXusIa6Cabl4wDw",
        "to add": False,
        "title": "200% ASMR | layered Unintelligible Whispering & Scalp Scratching - rain, no talking",
        "duration": 1371.0,
        "is short": False,
    },
    "YojlEzAgdNI": {
        "upload day": "2023-10-04",
        "channel name": "ASMR_Divinity",
        "upload playlist": "UU_n9r4yRVXusIa6Cabl4wDw",
        "to add": False,
        "title": "ASMR | most Sensitive Ear Attention & Breathing - no talking",
        "duration": 1428.0,
        "is short": False,
    },
    "2bi2Sro1zIE": {
        "upload day": "2023-04-16",
        "channel name": "ASMR_Divinity_DE",
        "upload playlist": "UUe6O7NLQE9Rvvcu9Jx3buEw",
        "to add": False,
        "title": "ASMR semi inaudible whispering - Flüstern und Hand Sounds (deutsch, german)",
        "duration": 1005.0,
        "is short": False,
    },
    "-XMz7ayx7I4": {
        "upload day": "2023-04-09",
        "channel name": "ASMR_Divinity_DE",
        "upload playlist": "UUe6O7NLQE9Rvvcu9Jx3buEw",
        "to add": False,
        "title": "ASMR 3dio Tapping & Scratching, Trigger Words, Shhh (deutsch, german)",
        "duration": 1267.0,
        "is short": False,
    },
    "dI2oRROlLqg": {
        "upload day": "2023-04-02",
        "channel name": "ASMR_Divinity_DE",
        "upload playlist": "UUe6O7NLQE9Rvvcu9Jx3buEw",
        "to add": False,
        "title": "ASMR extra close up Personal Attention und Visuals für dich  (deutsch, german)",
        "duration": 1259.0,
        "is short": False,
    },
    "YYETbX1Va1s": {
        "upload day": "2023-03-26",
        "channel name": "ASMR_Divinity_DE",
        "upload playlist": "UUe6O7NLQE9Rvvcu9Jx3buEw",
        "to add": False,
        "title": "ASMR Knister Schaum, Soft Spoken, Brushing  (deutsch, german)",
        "duration": 1127.0,
        "is short": False,
    },
    "LZlJrjcErCA": {
        "upload day": "2023-03-19",
        "channel name": "ASMR_Divinity_DE",
        "upload playlist": "UUe6O7NLQE9Rvvcu9Jx3buEw",
        "to add": False,
        "title": "ASMR Trigger Items die ich nie verwende (deutsch, german)",
        "duration": 1263.0,
        "is short": False,
    },
    "DJx2zwB_49M": {
        "upload day": "2023-06-17",
        "channel name": "ASMRSurge",
        "upload playlist": "UUIKOy_q2VWDv1vzeoi7KgNw",
        "to add": False,
        "title": "ASMR Back scratching (no talking)",
        "duration": 929.0,
        "is short": False,
    },
    "wO95xZC7pJo": {
        "upload day": "2023-06-14",
        "channel name": "ASMRSurge",
        "upload playlist": "UUIKOy_q2VWDv1vzeoi7KgNw",
        "to add": False,
        "title": "Cat eating ASMR",
        "duration": 487.0,
        "is short": False,
    },
    "eQ_7YFyHCQg": {
        "upload day": "2023-06-12",
        "channel name": "ASMRSurge",
        "upload playlist": "UUIKOy_q2VWDv1vzeoi7KgNw",
        "to add": False,
        "title": "ASMR Clicky-clacky rolling",
        "duration": 990.0,
        "is short": False,
    },
    "50rrGNgAZRo": {
        "upload day": "2023-06-07",
        "channel name": "ASMRSurge",
        "upload playlist": "UUIKOy_q2VWDv1vzeoi7KgNw",
        "to add": False,
        "title": "ASMR Trammeling in Nature",
        "duration": 1650.0,
        "is short": False,
    },
    "NI8C4rG3LsE": {
        "upload day": "2023-06-05",
        "channel name": "ASMRSurge",
        "upload playlist": "UUIKOy_q2VWDv1vzeoi7KgNw",
        "to add": False,
        "title": "ASMR B roller (no talking)",
        "duration": 890.0,
        "is short": False,
    },
    "X8R6HYy77bY": {
        "upload day": "2023-08-28",
        "channel name": "ASMRuOK ?",
        "upload playlist": "UU_cMthuWcW5rg_eVvStyOtg",
        "to add": False,
        "title": "ASMR - Get ready with me! 💄 (sans parler 🤫)",
        "duration": 1777.0,
        "is short": False,
    },
    "lJZ82GxBtuw": {
        "upload day": "2023-08-20",
        "channel name": "ASMRuOK ?",
        "upload playlist": "UU_cMthuWcW5rg_eVvStyOtg",
        "to add": False,
        "title": "ASMR - Je lis un livre en INAUDIBLE ✨ (mouth sounds intenses)",
        "duration": 1312.0,
        "is short": False,
    },
    "DthSIEop8Rk": {
        "upload day": "2023-08-16",
        "channel name": "ASMRuOK ?",
        "upload playlist": "UU_cMthuWcW5rg_eVvStyOtg",
        "to add": False,
        "title": "ASMR - Les moments LES PLUS POPULAIRES dans mes vidéos! ✨ 😴",
        "duration": 1109.0,
        "is short": False,
    },
    "egD3R-zIlOg": {
        "upload day": "2023-08-09",
        "channel name": "ASMRuOK ?",
        "upload playlist": "UU_cMthuWcW5rg_eVvStyOtg",
        "to add": False,
        "title": "ASMR - Les meilleurs TRIGGER WORDS! 😴 *chuchotements intenses + mouth  sounds* ✨",
        "duration": 1857.0,
        "is short": False,
    },
    "EGn9Bg1peIE": {
        "upload day": "2023-08-06",
        "channel name": "ASMRuOK ?",
        "upload playlist": "UU_cMthuWcW5rg_eVvStyOtg",
        "to add": False,
        "title": "ASMR - Vidéo à écouter les yeux fermés! 😴  💤",
        "duration": 1299.0,
        "is short": False,
    },
    "daoIPb6pbP0": {
        "upload day": "2021-08-22",
        "channel name": "Bright Grey ASMR",
        "upload playlist": "UU53vVuTxfTUPZSZVPW1iitg",
        "to add": False,
        "title": "Moving In: Stardew Valley | Bright Grey ASMR Live",
        "duration": 0.0,
        "is short": True,
    },
    "C3uYWjQG4dI": {
        "upload day": "2021-08-17",
        "channel name": "Bright Grey ASMR",
        "upload playlist": "UU53vVuTxfTUPZSZVPW1iitg",
        "to add": False,
        "title": "ASMR POV: You Are A Medieval Monk [Meditative Painting + Relaxing Music]",
        "duration": 2088.0,
        "is short": False,
    },
    "Z88HG1JRYtQ": {
        "upload day": "2020-09-28",
        "channel name": "Bright Grey ASMR",
        "upload playlist": "UU53vVuTxfTUPZSZVPW1iitg",
        "to add": False,
        "title": "ASMR | Dynamic Hand Sounds No. 2 | 1 Hour",
        "duration": 3623.0,
        "is short": False,
    },
    "ndovKIJzGxk": {
        "upload day": "2020-09-20",
        "channel name": "Bright Grey ASMR",
        "upload playlist": "UU53vVuTxfTUPZSZVPW1iitg",
        "to add": False,
        "title": "ASMR Hotline | Various Triggers | 1 hour",
        "duration": 3631.0,
        "is short": False,
    },
    "07V2BlgkrkY": {
        "upload day": "2020-09-04",
        "channel name": "Bright Grey ASMR",
        "upload playlist": "UU53vVuTxfTUPZSZVPW1iitg",
        "to add": False,
        "title": "ASMR | Facial Massage for Headache Relief [NO TALKING]",
        "duration": 1399.0,
        "is short": False,
    },
    "uLUHJQfElS0": {
        "upload day": "2023-10-10",
        "channel name": "Eevy ASMR",
        "upload playlist": "UUvjJat2_IdezGfh2_pAdRwQ",
        "to add": False,
        "title": "ASMR - Tapping & Scratching w/ Different Mini Mics",
        "duration": 1228.0,
        "is short": False,
    },
    "FPNuChjUzQM": {
        "upload day": "2023-10-07",
        "channel name": "Eevy ASMR",
        "upload playlist": "UUvjJat2_IdezGfh2_pAdRwQ",
        "to add": False,
        "title": "ASMR in the Rain - Fast Tapping Outdoors",
        "duration": 893.0,
        "is short": False,
    },
    "7_62BusK_HU": {
        "upload day": "2023-10-05",
        "channel name": "Eevy ASMR",
        "upload playlist": "UUvjJat2_IdezGfh2_pAdRwQ",
        "to add": False,
        "title": "Tapping around Vintage Air BNB - ASMR w/ friends",
        "duration": 1251.0,
        "is short": False,
    },
    "ygjV_cgnu-Q": {
        "upload day": "2023-10-02",
        "channel name": "Eevy ASMR",
        "upload playlist": "UUvjJat2_IdezGfh2_pAdRwQ",
        "to add": False,
        "title": "ASMR Rode Mic Test - Fast Tapping & Scratching",
        "duration": 820.0,
        "is short": False,
    },
    "3vNsQFbXTI4": {
        "upload day": "2023-09-28",
        "channel name": "Eevy ASMR",
        "upload playlist": "UUvjJat2_IdezGfh2_pAdRwQ",
        "to add": False,
        "title": "Outdoors ASMR tapping & scratching tour",
        "duration": 1031.0,
        "is short": False,
    },
    "1WHsHfpwBjU": {
        "upload day": "2023-10-11",
        "channel name": "Elena ASMR",
        "upload playlist": "UURQAFkl4BDOokg_R35Uqj1A",
        "to add": True,
        "title": "ASMR | FAST AND AGGRESSIVE MOUTH SOUNDS (wet & crunchy) wrapper sounds, hand movements *tingly*",
        "duration": 1459.0,
        "is short": False,
    },
    "qOJ7J3p34xI": {
        "upload day": "2023-10-04",
        "channel name": "Elena ASMR",
        "upload playlist": "UURQAFkl4BDOokg_R35Uqj1A",
        "to add": False,
        "title": "ASMR | 45 MINUTES OF FAST & AGGRESSIVE ASMR (mouth sounds, tapping, mic triggers, visualizations)",
        "duration": 2734.0,
        "is short": False,
    },
    "BlgWJIHoYno": {
        "upload day": "2023-09-27",
        "channel name": "Elena ASMR",
        "upload playlist": "UURQAFkl4BDOokg_R35Uqj1A",
        "to add": False,
        "title": "ASMR | FAST AND AGGRESSIVE MOUTH SOUNDS WITH HAND MOVEMENTS (with spit painting)",
        "duration": 1855.0,
        "is short": False,
    },
    "9fQwKvalD38": {
        "upload day": "2023-09-20",
        "channel name": "Elena ASMR",
        "upload playlist": "UURQAFkl4BDOokg_R35Uqj1A",
        "to add": False,
        "title": "ASMR | FAST AND AGGRESSIVE ASMR FOR ADHD (Pay Attention & Follow my Instructions) *99.9% will fail*",
        "duration": 2427.0,
        "is short": False,
    },
    "1vM3QYTrQro": {
        "upload day": "2023-09-06",
        "channel name": "Elena ASMR",
        "upload playlist": "UURQAFkl4BDOokg_R35Uqj1A",
        "to add": False,
        "title": "ASMR for ADHD | UNPREDICTABLE FAST & AGGRESSIVE TRIGGERS (Mouth Sounds, Pay Attention + Focus)",
        "duration": 1817.0,
        "is short": False,
    },
    "TwhVixRKnp8": {
        "upload day": "2023-10-09",
        "channel name": "Fast Tingles ASMR",
        "upload playlist": "UUN3uA52_BqWJavWdHVh4SEg",
        "to add": False,
        "title": "ASMR - Super FAST and AGGRESSIVE SCALP SCRATCHING MASSAGE | mic scratching FLUFFY cover | NO talking",
        "duration": 3911.0,
        "is short": False,
    },
    "rrTgU4JeADk": {
        "upload day": "2023-10-06",
        "channel name": "Fast Tingles ASMR",
        "upload playlist": "UUN3uA52_BqWJavWdHVh4SEg",
        "to add": False,
        "title": "ASMR - 1 HOUR FAST AND AGGRESSIVE MIC SCRATCHING without cover for intense tingles | No talking",
        "duration": 4440.0,
        "is short": False,
    },
    "-8nRegmGmp8": {
        "upload day": "2023-10-02",
        "channel name": "Fast Tingles ASMR",
        "upload playlist": "UUN3uA52_BqWJavWdHVh4SEg",
        "to add": False,
        "title": "ASMR - FAST and AGGRESSIVE SCALP SCRATCHING MASSAGE | mic scratching with mic cover | Soft Spoken",
        "duration": 1187.0,
        "is short": False,
    },
    "7BN88Xo_QSk": {
        "upload day": "2023-09-29",
        "channel name": "Fast Tingles ASMR",
        "upload playlist": "UUN3uA52_BqWJavWdHVh4SEg",
        "to add": False,
        "title": "ASMR - FAST and AGGRESSIVE SCRATCHING MASSAGE | FLUFFY Mic Cover | INTENSE Sounds | No talking",
        "duration": 1427.0,
        "is short": False,
    },
    "1LrQQisxV7w": {
        "upload day": "2023-09-25",
        "channel name": "Fast Tingles ASMR",
        "upload playlist": "UUN3uA52_BqWJavWdHVh4SEg",
        "to add": False,
        "title": "ASMR - 1 HOUR FAST AGGRESSIVE MIC COVER PUMPING, SWIRLING, Rubbing with ITA/ENG tingly whispering 😍",
        "duration": 3708.0,
        "is short": False,
    },
    "odQ5XbzpdVw": {
        "upload day": "2023-10-11",
        "channel name": "fastASMR",
        "upload playlist": "UUHiof82PvgZrXFF-BRMvGDg",
        "to add": True,
        "title": "ASMRtist Check ✅ #asmr #shorts #asmrmissmi #asmrshorts",
        "duration": 60.0,
        "is short": True,
    },
    "HA_hl_fhvnY": {
        "upload day": "2023-10-10",
        "channel name": "fastASMR",
        "upload playlist": "UUHiof82PvgZrXFF-BRMvGDg",
        "to add": False,
        "title": "ASMR 200% Sensitive Whispering You Can FEEL in Your Ears 🤯",
        "duration": 1607.0,
        "is short": False,
    },
    "9CaO-wF0qZg": {
        "upload day": "2023-10-08",
        "channel name": "fastASMR",
        "upload playlist": "UUHiof82PvgZrXFF-BRMvGDg",
        "to add": False,
        "title": "ASMR for People Who Can't Get Tingles",
        "duration": 1327.0,
        "is short": False,
    },
    "tbdISugMkus": {
        "upload day": "2023-10-05",
        "channel name": "fastASMR",
        "upload playlist": "UUHiof82PvgZrXFF-BRMvGDg",
        "to add": False,
        "title": "Doing ASMR But You Are the ASMRtist",
        "duration": 1357.0,
        "is short": False,
    },
    "ZpKoaiIt2YY": {
        "upload day": "2023-10-04",
        "channel name": "fastASMR",
        "upload playlist": "UUHiof82PvgZrXFF-BRMvGDg",
        "to add": False,
        "title": "ASMR Testing Your Intuition #asmr #shorts #asmrshorts",
        "duration": 60.0,
        "is short": True,
    },
    "hZnCu7LWE4o": {
        "upload day": "2023-10-11",
        "channel name": "FruityPatchouli ASMR",
        "upload playlist": "UUvc9QhLhEWHQLWwv2Isp12g",
        "to add": True,
        "title": "ASMR 👀 Fast & Aggressive Peripheral Triggers (Visuals)",
        "duration": 2313.0,
        "is short": False,
    },
    "qPQzptqb2MQ": {
        "upload day": "2023-10-05",
        "channel name": "FruityPatchouli ASMR",
        "upload playlist": "UUvc9QhLhEWHQLWwv2Isp12g",
        "to add": False,
        "title": "Fast Aggressive ASMR | Anticipatory Triggers, Bubble Pop, Setting & Breaking the Pattern",
        "duration": 1178.0,
        "is short": False,
    },
    "KAgjwss5ANY": {
        "upload day": "2023-10-02",
        "channel name": "FruityPatchouli ASMR",
        "upload playlist": "UUvc9QhLhEWHQLWwv2Isp12g",
        "to add": False,
        "title": "ASMR with TAD (The Acupuncture Doll) - Massaging Your Back, Chest + More",
        "duration": 1921.0,
        "is short": False,
    },
    "HYEJucwaTWU": {
        "upload day": "2023-09-29",
        "channel name": "FruityPatchouli ASMR",
        "upload playlist": "UUvc9QhLhEWHQLWwv2Isp12g",
        "to add": False,
        "title": "THIS or THAT? | Fast Aggressive ASMR Hand Movements, Mouth Sounds & Personal Attention",
        "duration": 1590.0,
        "is short": False,
    },
    "x3Hhhge_LVg": {
        "upload day": "2023-09-22",
        "channel name": "FruityPatchouli ASMR",
        "upload playlist": "UUvc9QhLhEWHQLWwv2Isp12g",
        "to add": False,
        "title": "ASMR Fast Paced, Chaotic Touching (massaging, taking measurements, applying products)",
        "duration": 1208.0,
        "is short": False,
    },
    "9quOJ93UpnQ": {
        "upload day": "2020-04-06",
        "channel name": "Heather Feather ASMR",
        "upload playlist": "UU2eddeJoyByJBjE4CYXwNXQ",
        "to add": False,
        "title": "1 Hour ASMR Squishy-fest | 25 Squishies To Decompress Your Stress Away",
        "duration": 3901.0,
        "is short": False,
    },
    "vcSkoOdvFyA": {
        "upload day": "2020-04-01",
        "channel name": "Heather Feather ASMR",
        "upload playlist": "UU2eddeJoyByJBjE4CYXwNXQ",
        "to add": False,
        "title": "The Sweetest ASMR Role Play",
        "duration": 1409.0,
        "is short": False,
    },
    "YYuIIW8RQZo": {
        "upload day": "2020-03-28",
        "channel name": "Heather Feather ASMR",
        "upload playlist": "UU2eddeJoyByJBjE4CYXwNXQ",
        "to add": False,
        "title": "ASMR Sci-Fi Head Massage Sound Slice",
        "duration": 1414.0,
        "is short": False,
    },
    "ceX9nophCgw": {
        "upload day": "2020-02-17",
        "channel name": "Heather Feather ASMR",
        "upload playlist": "UU2eddeJoyByJBjE4CYXwNXQ",
        "to add": False,
        "title": "ASMR Neuro-ophthalmology Examination",
        "duration": 1910.0,
        "is short": False,
    },
    "1DTS2rA71cw": {
        "upload day": "2020-02-02",
        "channel name": "Heather Feather ASMR",
        "upload playlist": "UU2eddeJoyByJBjE4CYXwNXQ",
        "to add": False,
        "title": "ASMR Super Bowl 2020 | Literally Super Bowls | No Talking",
        "duration": 1293.0,
        "is short": False,
    },
    "oCtxP3a8lkI": {
        "upload day": "2020-07-16",
        "channel name": "JellybeanASMR",
        "upload playlist": "UUCjpp4TCjnRftS_LenXuSHw",
        "to add": False,
        "title": "[ASMR] Ear Massage & Soft Whispering in Bed to Help You Fall Asleep",
        "duration": 1352.0,
        "is short": False,
    },
    "gfSdPHWkTcE": {
        "upload day": "2020-03-18",
        "channel name": "JellybeanASMR",
        "upload playlist": "UUCjpp4TCjnRftS_LenXuSHw",
        "to add": False,
        "title": "[ASMR] Unintelligible Whispering | Ear Touching | Soft Breathing | Mouth Sounds",
        "duration": 2093.0,
        "is short": False,
    },
    "I4WxAE7beE0": {
        "upload day": "2019-09-18",
        "channel name": "JellybeanASMR",
        "upload playlist": "UUCjpp4TCjnRftS_LenXuSHw",
        "to add": False,
        "title": "[ASMR] Ear Massage + Close Up Whispering + Humming",
        "duration": 1620.0,
        "is short": False,
    },
    "nkQxJ8O9f-U": {
        "upload day": "2019-09-07",
        "channel name": "JellybeanASMR",
        "upload playlist": "UUCjpp4TCjnRftS_LenXuSHw",
        "to add": False,
        "title": "[ASMR] Study Session with a Friend (Soft Spoken, Tapping, Page Turning, Pencil Sounds)",
        "duration": 1622.0,
        "is short": False,
    },
}

mock_short_videos = {
    "r980Y7QtcVQ": {
        "upload day": "2023-08-08",
        "channel name": "Adequate ASMR",
        "upload playlist": "UU_4CsQXbCI1LV7dug83qL8A",
        "to add": True,
        "title": "ASMR Inaudible,👌😍 Unintelligible, 😍and Kisses",
        "duration": 1549.0,
        "is short": False,
    },
    "QiJZ6aWt3X4": {
        "upload day": "2023-08-04",
        "channel name": "Adequate ASMR",
        "upload playlist": "UU_4CsQXbCI1LV7dug83qL8A",
        "to add": True,
        "title": "Hand and Mouth Sounds ASMR",
        "duration": 1061.0,
        "is short": False,
    },
    "brsI6OPZrPg": {
        "upload day": "2022-10-14",
        "channel name": "Adequate ASMR",
        "upload playlist": "UU_4CsQXbCI1LV7dug83qL8A",
        "to add": True,
        "title": "😍Fast, intense mouth sounds, hand sounds, inaudible/unintelligible ASMR😍",
        "duration": 1059.0,
        "is short": False,
    },
    "mdCPAuW6JPU": {
        "upload day": "2022-05-19",
        "channel name": "Adequate ASMR",
        "upload playlist": "UU_4CsQXbCI1LV7dug83qL8A",
        "to add": True,
        "title": "Fluffy Scalp Massage ASMR",
        "duration": 1228.0,
        "is short": False,
    },
    "fMTkMZv4gxo": {
        "upload day": "2022-05-12",
        "channel name": "Adequate ASMR",
        "upload playlist": "UU_4CsQXbCI1LV7dug83qL8A",
        "to add": True,
        "title": "😍😍Tongue, Teeth, and Mouth Sounds ASMR😍😍😍",
        "duration": 2145.0,
        "is short": False,
    },
}

mock_one_vid_videos = {
    "r980Y7QtcVQ": {
        "upload day": "2023-08-08",
        "channel name": "Adequate ASMR",
        "upload playlist": "UU_4CsQXbCI1LV7dug83qL8A",
        "to add": False,
        "title": "ASMR Inaudible, Unintelligible, and Kisses",
        "duration": 1549.0,
        "is short": False,
    },
}

### Tests ###
videos = mock_short_videos
split_videos = utils.helpers.split_dict(videos, 50)

## TO DO

